/********************************************************************************
** Form generated from reading UI file 'ignorelisteditor.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IGNORELISTEDITOR_H
#define UI_IGNORELISTEDITOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "ignorelisttablewidget.h"
#include "settingsswitch.h"

namespace OCC {

class Ui_IgnoreListEditor
{
public:
    QVBoxLayout *dialogLayout;
    QFrame *globalIgnoreSettingsPanel;
    QVBoxLayout *globalIgnoreSettingsPanelLayout;
    QLabel *globalIgnoreSettingsPanelTitle;
    QWidget *globalIgnoreSettingsPanelContents;
    QVBoxLayout *globalIgnoreSettingsLayout;
    QHBoxLayout *syncHiddenFilesRow;
    QLabel *syncHiddenFilesLabel;
    QSpacerItem *syncHiddenFilesSpacer;
    OCC::SettingsSwitch *syncHiddenFilesCheckBox;
    QFrame *ignoredPatternsPanel;
    QVBoxLayout *ignoredPatternsPanelLayout;
    QLabel *ignoredPatternsPanelTitle;
    QWidget *ignoredPatternsPanelContents;
    QVBoxLayout *ignoredPatternsLayout;
    IgnoreListTableWidget *ignoreTableWidget;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *OCC__IgnoreListEditor)
    {
        if (OCC__IgnoreListEditor->objectName().isEmpty())
            OCC__IgnoreListEditor->setObjectName("OCC__IgnoreListEditor");
        OCC__IgnoreListEditor->resize(555, 609);
        dialogLayout = new QVBoxLayout(OCC__IgnoreListEditor);
        dialogLayout->setObjectName("dialogLayout");
        globalIgnoreSettingsPanel = new QFrame(OCC__IgnoreListEditor);
        globalIgnoreSettingsPanel->setObjectName("globalIgnoreSettingsPanel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(globalIgnoreSettingsPanel->sizePolicy().hasHeightForWidth());
        globalIgnoreSettingsPanel->setSizePolicy(sizePolicy);
        globalIgnoreSettingsPanel->setFrameShape(QFrame::Shape::NoFrame);
        globalIgnoreSettingsPanelLayout = new QVBoxLayout(globalIgnoreSettingsPanel);
        globalIgnoreSettingsPanelLayout->setObjectName("globalIgnoreSettingsPanelLayout");
        globalIgnoreSettingsPanelLayout->setSizeConstraint(QLayout::SizeConstraint::SetDefaultConstraint);
        globalIgnoreSettingsPanelTitle = new QLabel(globalIgnoreSettingsPanel);
        globalIgnoreSettingsPanelTitle->setObjectName("globalIgnoreSettingsPanelTitle");
        QFont font;
        font.setBold(true);
        globalIgnoreSettingsPanelTitle->setFont(font);

        globalIgnoreSettingsPanelLayout->addWidget(globalIgnoreSettingsPanelTitle);

        globalIgnoreSettingsPanelContents = new QWidget(globalIgnoreSettingsPanel);
        globalIgnoreSettingsPanelContents->setObjectName("globalIgnoreSettingsPanelContents");
        globalIgnoreSettingsLayout = new QVBoxLayout(globalIgnoreSettingsPanelContents);
        globalIgnoreSettingsLayout->setObjectName("globalIgnoreSettingsLayout");
        globalIgnoreSettingsLayout->setContentsMargins(0, 0, 0, 0);
        syncHiddenFilesRow = new QHBoxLayout();
        syncHiddenFilesRow->setObjectName("syncHiddenFilesRow");
        syncHiddenFilesLabel = new QLabel(globalIgnoreSettingsPanelContents);
        syncHiddenFilesLabel->setObjectName("syncHiddenFilesLabel");

        syncHiddenFilesRow->addWidget(syncHiddenFilesLabel);

        syncHiddenFilesSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        syncHiddenFilesRow->addItem(syncHiddenFilesSpacer);

        syncHiddenFilesCheckBox = new OCC::SettingsSwitch(globalIgnoreSettingsPanelContents);
        syncHiddenFilesCheckBox->setObjectName("syncHiddenFilesCheckBox");

        syncHiddenFilesRow->addWidget(syncHiddenFilesCheckBox);


        globalIgnoreSettingsLayout->addLayout(syncHiddenFilesRow);


        globalIgnoreSettingsPanelLayout->addWidget(globalIgnoreSettingsPanelContents);


        dialogLayout->addWidget(globalIgnoreSettingsPanel);

        ignoredPatternsPanel = new QFrame(OCC__IgnoreListEditor);
        ignoredPatternsPanel->setObjectName("ignoredPatternsPanel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(1);
        sizePolicy1.setHeightForWidth(ignoredPatternsPanel->sizePolicy().hasHeightForWidth());
        ignoredPatternsPanel->setSizePolicy(sizePolicy1);
        ignoredPatternsPanel->setFrameShape(QFrame::Shape::NoFrame);
        ignoredPatternsPanelLayout = new QVBoxLayout(ignoredPatternsPanel);
        ignoredPatternsPanelLayout->setObjectName("ignoredPatternsPanelLayout");
        ignoredPatternsPanelLayout->setSizeConstraint(QLayout::SizeConstraint::SetDefaultConstraint);
        ignoredPatternsPanelTitle = new QLabel(ignoredPatternsPanel);
        ignoredPatternsPanelTitle->setObjectName("ignoredPatternsPanelTitle");
        ignoredPatternsPanelTitle->setFont(font);

        ignoredPatternsPanelLayout->addWidget(ignoredPatternsPanelTitle);

        ignoredPatternsPanelContents = new QWidget(ignoredPatternsPanel);
        ignoredPatternsPanelContents->setObjectName("ignoredPatternsPanelContents");
        sizePolicy1.setHeightForWidth(ignoredPatternsPanelContents->sizePolicy().hasHeightForWidth());
        ignoredPatternsPanelContents->setSizePolicy(sizePolicy1);
        ignoredPatternsLayout = new QVBoxLayout(ignoredPatternsPanelContents);
        ignoredPatternsLayout->setObjectName("ignoredPatternsLayout");
        ignoredPatternsLayout->setContentsMargins(0, 0, 0, 0);
        ignoreTableWidget = new IgnoreListTableWidget(ignoredPatternsPanelContents);
        ignoreTableWidget->setObjectName("ignoreTableWidget");

        ignoredPatternsLayout->addWidget(ignoreTableWidget);


        ignoredPatternsPanelLayout->addWidget(ignoredPatternsPanelContents);


        dialogLayout->addWidget(ignoredPatternsPanel);

        buttonBox = new QDialogButtonBox(OCC__IgnoreListEditor);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::RestoreDefaults);

        dialogLayout->addWidget(buttonBox);

#if QT_CONFIG(shortcut)
        syncHiddenFilesLabel->setBuddy(syncHiddenFilesCheckBox);
#endif // QT_CONFIG(shortcut)

        retranslateUi(OCC__IgnoreListEditor);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, OCC__IgnoreListEditor, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, OCC__IgnoreListEditor, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(OCC__IgnoreListEditor);
    } // setupUi

    void retranslateUi(QDialog *OCC__IgnoreListEditor)
    {
        OCC__IgnoreListEditor->setWindowTitle(QCoreApplication::translate("OCC::IgnoreListEditor", "Ignored Files Editor", nullptr));
        globalIgnoreSettingsPanelTitle->setText(QCoreApplication::translate("OCC::IgnoreListEditor", "Global Ignore Settings", nullptr));
        syncHiddenFilesLabel->setText(QCoreApplication::translate("OCC::IgnoreListEditor", "Sync hidden files", nullptr));
        ignoredPatternsPanelTitle->setText(QCoreApplication::translate("OCC::IgnoreListEditor", "Files Ignored by Patterns", nullptr));
    } // retranslateUi

};

} // namespace OCC

namespace OCC {
namespace Ui {
    class IgnoreListEditor: public Ui_IgnoreListEditor {};
} // namespace Ui
} // namespace OCC

#endif // UI_IGNORELISTEDITOR_H
