/********************************************************************************
** Form generated from reading UI file 'generalsettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GENERALSETTINGS_H
#define UI_GENERALSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "settingsswitch.h"

namespace OCC {

class Ui_GeneralSettings
{
public:
    QVBoxLayout *pageLayout;
    QGroupBox *generalGroupBox;
    QVBoxLayout *generalSettingsLayout;
    QHBoxLayout *autostartRow;
    QLabel *autostartLabel;
    QSpacerItem *autostartSpacer;
    OCC::SettingsSwitch *autostartCheckBox;
    QFrame *startupSeparator;
    QWidget *monoIconsRowWidget;
    QHBoxLayout *monoIconsRow;
    QLabel *monoIconsLabel;
    QSpacerItem *monoIconsSpacer;
    OCC::SettingsSwitch *monoIconsCheckBox;
    QGroupBox *fileProviderGroupBox;
    QVBoxLayout *fileProviderSettingsLayout;
    QHBoxLayout *fileProviderRow;
    QLabel *fileProviderLabel;
    QSpacerItem *fileProviderSpacer;
    OCC::SettingsSwitch *fileProviderCheckBox;
    QHBoxLayout *fileProviderDescriptionRow;
    QLabel *fileProviderDescriptionLabel;
    QGroupBox *notificationsGroupBox;
    QVBoxLayout *notificationsSettingsLayout;
    QHBoxLayout *serverNotificationsRow;
    QLabel *serverNotificationsLabel;
    QSpacerItem *serverNotificationsSpacer;
    OCC::SettingsSwitch *serverNotificationsCheckBox;
    QFrame *serverNotificationsSeparator;
    QHBoxLayout *chatNotificationsRow;
    QLabel *chatNotificationsLabel;
    QSpacerItem *chatNotificationsSpacer;
    OCC::SettingsSwitch *chatNotificationsCheckBox;
    QFrame *chatNotificationsSeparator;
    QHBoxLayout *callNotificationsRow;
    QLabel *callNotificationsLabel;
    QSpacerItem *callNotificationsSpacer;
    OCC::SettingsSwitch *callNotificationsCheckBox;
    QFrame *callNotificationsSeparator;
    QHBoxLayout *quotaWarningNotificationsRow;
    QLabel *quotaWarningNotificationsLabel;
    QSpacerItem *quotaWarningNotificationsSpacer;
    OCC::SettingsSwitch *quotaWarningNotificationsCheckBox;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *OCC__GeneralSettings)
    {
        if (OCC__GeneralSettings->objectName().isEmpty())
            OCC__GeneralSettings->setObjectName("OCC__GeneralSettings");
        OCC__GeneralSettings->resize(667, 300);
        OCC__GeneralSettings->setWindowTitle(QString::fromUtf8("Form"));
        pageLayout = new QVBoxLayout(OCC__GeneralSettings);
        pageLayout->setSpacing(12);
        pageLayout->setObjectName("pageLayout");
        pageLayout->setContentsMargins(0, 0, 0, 0);
        generalGroupBox = new QGroupBox(OCC__GeneralSettings);
        generalGroupBox->setObjectName("generalGroupBox");
        generalSettingsLayout = new QVBoxLayout(generalGroupBox);
        generalSettingsLayout->setSpacing(0);
        generalSettingsLayout->setObjectName("generalSettingsLayout");
        autostartRow = new QHBoxLayout();
        autostartRow->setObjectName("autostartRow");
        autostartLabel = new QLabel(generalGroupBox);
        autostartLabel->setObjectName("autostartLabel");

        autostartRow->addWidget(autostartLabel);

        autostartSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        autostartRow->addItem(autostartSpacer);

        autostartCheckBox = new OCC::SettingsSwitch(generalGroupBox);
        autostartCheckBox->setObjectName("autostartCheckBox");

        autostartRow->addWidget(autostartCheckBox);


        generalSettingsLayout->addLayout(autostartRow);

        startupSeparator = new QFrame(generalGroupBox);
        startupSeparator->setObjectName("startupSeparator");
        startupSeparator->setFrameShape(QFrame::Shape::HLine);
        startupSeparator->setFrameShadow(QFrame::Shadow::Plain);

        generalSettingsLayout->addWidget(startupSeparator);

        monoIconsRowWidget = new QWidget(generalGroupBox);
        monoIconsRowWidget->setObjectName("monoIconsRowWidget");
        monoIconsRow = new QHBoxLayout(monoIconsRowWidget);
        monoIconsRow->setObjectName("monoIconsRow");
        monoIconsRow->setContentsMargins(0, 0, 0, 0);
        monoIconsLabel = new QLabel(monoIconsRowWidget);
        monoIconsLabel->setObjectName("monoIconsLabel");

        monoIconsRow->addWidget(monoIconsLabel);

        monoIconsSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        monoIconsRow->addItem(monoIconsSpacer);

        monoIconsCheckBox = new OCC::SettingsSwitch(monoIconsRowWidget);
        monoIconsCheckBox->setObjectName("monoIconsCheckBox");

        monoIconsRow->addWidget(monoIconsCheckBox);


        generalSettingsLayout->addWidget(monoIconsRowWidget);


        pageLayout->addWidget(generalGroupBox);

        fileProviderGroupBox = new QGroupBox(OCC__GeneralSettings);
        fileProviderGroupBox->setObjectName("fileProviderGroupBox");
        fileProviderSettingsLayout = new QVBoxLayout(fileProviderGroupBox);
        fileProviderSettingsLayout->setSpacing(0);
        fileProviderSettingsLayout->setObjectName("fileProviderSettingsLayout");
        fileProviderRow = new QHBoxLayout();
        fileProviderRow->setObjectName("fileProviderRow");
        fileProviderLabel = new QLabel(fileProviderGroupBox);
        fileProviderLabel->setObjectName("fileProviderLabel");

        fileProviderRow->addWidget(fileProviderLabel);

        fileProviderSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        fileProviderRow->addItem(fileProviderSpacer);

        fileProviderCheckBox = new OCC::SettingsSwitch(fileProviderGroupBox);
        fileProviderCheckBox->setObjectName("fileProviderCheckBox");

        fileProviderRow->addWidget(fileProviderCheckBox);


        fileProviderSettingsLayout->addLayout(fileProviderRow);

        fileProviderDescriptionRow = new QHBoxLayout();
        fileProviderDescriptionRow->setObjectName("fileProviderDescriptionRow");
        fileProviderDescriptionLabel = new QLabel(fileProviderGroupBox);
        fileProviderDescriptionLabel->setObjectName("fileProviderDescriptionLabel");
        fileProviderDescriptionLabel->setWordWrap(true);

        fileProviderDescriptionRow->addWidget(fileProviderDescriptionLabel);


        fileProviderSettingsLayout->addLayout(fileProviderDescriptionRow);


        pageLayout->addWidget(fileProviderGroupBox);

        notificationsGroupBox = new QGroupBox(OCC__GeneralSettings);
        notificationsGroupBox->setObjectName("notificationsGroupBox");
        notificationsSettingsLayout = new QVBoxLayout(notificationsGroupBox);
        notificationsSettingsLayout->setSpacing(0);
        notificationsSettingsLayout->setObjectName("notificationsSettingsLayout");
        serverNotificationsRow = new QHBoxLayout();
        serverNotificationsRow->setObjectName("serverNotificationsRow");
        serverNotificationsLabel = new QLabel(notificationsGroupBox);
        serverNotificationsLabel->setObjectName("serverNotificationsLabel");

        serverNotificationsRow->addWidget(serverNotificationsLabel);

        serverNotificationsSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        serverNotificationsRow->addItem(serverNotificationsSpacer);

        serverNotificationsCheckBox = new OCC::SettingsSwitch(notificationsGroupBox);
        serverNotificationsCheckBox->setObjectName("serverNotificationsCheckBox");

        serverNotificationsRow->addWidget(serverNotificationsCheckBox);


        notificationsSettingsLayout->addLayout(serverNotificationsRow);

        serverNotificationsSeparator = new QFrame(notificationsGroupBox);
        serverNotificationsSeparator->setObjectName("serverNotificationsSeparator");
        serverNotificationsSeparator->setFrameShape(QFrame::Shape::HLine);
        serverNotificationsSeparator->setFrameShadow(QFrame::Shadow::Plain);

        notificationsSettingsLayout->addWidget(serverNotificationsSeparator);

        chatNotificationsRow = new QHBoxLayout();
        chatNotificationsRow->setObjectName("chatNotificationsRow");
        chatNotificationsLabel = new QLabel(notificationsGroupBox);
        chatNotificationsLabel->setObjectName("chatNotificationsLabel");

        chatNotificationsRow->addWidget(chatNotificationsLabel);

        chatNotificationsSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        chatNotificationsRow->addItem(chatNotificationsSpacer);

        chatNotificationsCheckBox = new OCC::SettingsSwitch(notificationsGroupBox);
        chatNotificationsCheckBox->setObjectName("chatNotificationsCheckBox");

        chatNotificationsRow->addWidget(chatNotificationsCheckBox);


        notificationsSettingsLayout->addLayout(chatNotificationsRow);

        chatNotificationsSeparator = new QFrame(notificationsGroupBox);
        chatNotificationsSeparator->setObjectName("chatNotificationsSeparator");
        chatNotificationsSeparator->setFrameShape(QFrame::Shape::HLine);
        chatNotificationsSeparator->setFrameShadow(QFrame::Shadow::Plain);

        notificationsSettingsLayout->addWidget(chatNotificationsSeparator);

        callNotificationsRow = new QHBoxLayout();
        callNotificationsRow->setObjectName("callNotificationsRow");
        callNotificationsLabel = new QLabel(notificationsGroupBox);
        callNotificationsLabel->setObjectName("callNotificationsLabel");

        callNotificationsRow->addWidget(callNotificationsLabel);

        callNotificationsSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        callNotificationsRow->addItem(callNotificationsSpacer);

        callNotificationsCheckBox = new OCC::SettingsSwitch(notificationsGroupBox);
        callNotificationsCheckBox->setObjectName("callNotificationsCheckBox");

        callNotificationsRow->addWidget(callNotificationsCheckBox);


        notificationsSettingsLayout->addLayout(callNotificationsRow);

        callNotificationsSeparator = new QFrame(notificationsGroupBox);
        callNotificationsSeparator->setObjectName("callNotificationsSeparator");
        callNotificationsSeparator->setFrameShape(QFrame::Shape::HLine);
        callNotificationsSeparator->setFrameShadow(QFrame::Shadow::Plain);

        notificationsSettingsLayout->addWidget(callNotificationsSeparator);

        quotaWarningNotificationsRow = new QHBoxLayout();
        quotaWarningNotificationsRow->setObjectName("quotaWarningNotificationsRow");
        quotaWarningNotificationsLabel = new QLabel(notificationsGroupBox);
        quotaWarningNotificationsLabel->setObjectName("quotaWarningNotificationsLabel");

        quotaWarningNotificationsRow->addWidget(quotaWarningNotificationsLabel);

        quotaWarningNotificationsSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        quotaWarningNotificationsRow->addItem(quotaWarningNotificationsSpacer);

        quotaWarningNotificationsCheckBox = new OCC::SettingsSwitch(notificationsGroupBox);
        quotaWarningNotificationsCheckBox->setObjectName("quotaWarningNotificationsCheckBox");

        quotaWarningNotificationsRow->addWidget(quotaWarningNotificationsCheckBox);


        notificationsSettingsLayout->addLayout(quotaWarningNotificationsRow);


        pageLayout->addWidget(notificationsGroupBox);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        pageLayout->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        autostartLabel->setBuddy(autostartCheckBox);
        monoIconsLabel->setBuddy(monoIconsCheckBox);
        fileProviderLabel->setBuddy(fileProviderCheckBox);
        serverNotificationsLabel->setBuddy(serverNotificationsCheckBox);
        chatNotificationsLabel->setBuddy(chatNotificationsCheckBox);
        callNotificationsLabel->setBuddy(callNotificationsCheckBox);
        quotaWarningNotificationsLabel->setBuddy(quotaWarningNotificationsCheckBox);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(autostartCheckBox, monoIconsCheckBox);
        QWidget::setTabOrder(monoIconsCheckBox, fileProviderCheckBox);
        QWidget::setTabOrder(fileProviderCheckBox, serverNotificationsCheckBox);
        QWidget::setTabOrder(serverNotificationsCheckBox, chatNotificationsCheckBox);
        QWidget::setTabOrder(chatNotificationsCheckBox, callNotificationsCheckBox);
        QWidget::setTabOrder(callNotificationsCheckBox, quotaWarningNotificationsCheckBox);

        retranslateUi(OCC__GeneralSettings);

        QMetaObject::connectSlotsByName(OCC__GeneralSettings);
    } // setupUi

    void retranslateUi(QWidget *OCC__GeneralSettings)
    {
        generalGroupBox->setTitle(QString());
        autostartLabel->setText(QCoreApplication::translate("OCC::GeneralSettings", "&Launch on System Startup", nullptr));
        monoIconsLabel->setText(QCoreApplication::translate("OCC::GeneralSettings", "Use &Monochrome Icons", nullptr));
#if QT_CONFIG(tooltip)
        monoIconsCheckBox->setToolTip(QCoreApplication::translate("OCC::GeneralSettings", "For System Tray", nullptr));
#endif // QT_CONFIG(tooltip)
        fileProviderGroupBox->setTitle(QString());
        fileProviderLabel->setText(QCoreApplication::translate("OCC::GeneralSettings", "Enable &File Provider", nullptr));
        fileProviderDescriptionLabel->setText(QCoreApplication::translate("OCC::GeneralSettings", "Files appear in Finder under the \"Locations\" section and do not use local storage space; contents download automatically when you open a file. Applies to all accounts and replaces classic sync folders and their Finder integration.", nullptr));
        notificationsGroupBox->setTitle(QString());
        serverNotificationsLabel->setText(QCoreApplication::translate("OCC::GeneralSettings", "Show Server &Notifications", nullptr));
        chatNotificationsLabel->setText(QCoreApplication::translate("OCC::GeneralSettings", "Show Chat Notifications", nullptr));
        callNotificationsLabel->setText(QCoreApplication::translate("OCC::GeneralSettings", "Show Call Notifications", nullptr));
        quotaWarningNotificationsLabel->setText(QCoreApplication::translate("OCC::GeneralSettings", "Show &Quota Warning Notifications", nullptr));
        (void)OCC__GeneralSettings;
    } // retranslateUi

};

} // namespace OCC

namespace OCC {
namespace Ui {
    class GeneralSettings: public Ui_GeneralSettings {};
} // namespace Ui
} // namespace OCC

#endif // UI_GENERALSETTINGS_H
