/*
 * SPDX-FileCopyrightText: 2026 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: GPL-2.0-or-later
 */

#ifndef SETTINGSPANELSTYLE_H
#define SETTINGSPANELSTYLE_H

class QWidget;

namespace OCC::SettingsPanelStyle {

void apply(QWidget *root);

} // namespace OCC::SettingsPanelStyle

#endif // SETTINGSPANELSTYLE_H
