/*
 * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors
 * SPDX-FileCopyrightText: 2017 ownCloud, Inc.
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

#ifndef VERSION_H
#define VERSION_H

#define GIT_SHA1 "364596d2caca387c5027a4694890fb79c4177a0f"

#define MIRALL_STRINGIFY(s) MIRALL_TOSTRING(s)
#define MIRALL_TOSTRING(s) #s

/* MIRALL version */
constexpr auto MIRALL_VERSION_MAJOR = 34;
constexpr auto MIRALL_VERSION_MINOR = 0;
constexpr auto MIRALL_VERSION_PATCH = 1;
constexpr auto MIRALL_VERSION_BUILD = 0;
constexpr auto MIRALL_VERSION_SUFFIX = "daily";

#define MIRALL_VERSION       34.0.1
#define MIRALL_VERSION_FULL  34.0.1.0

#define MIRALL_VERSION_STRING "34.0.1daily"
#define MIRALL_HUMAN_VERSION_STRING "34.0.1daily"

constexpr int NEXTCLOUD_SERVER_VERSION_MIN_SUPPORTED_MAJOR = 20;
constexpr int NEXTCLOUD_SERVER_VERSION_MIN_SUPPORTED_MINOR = 0;
constexpr int NEXTCLOUD_SERVER_VERSION_MIN_SUPPORTED_PATCH = 0;

constexpr int NEXTCLOUD_SERVER_VERSION_SECURE_FILEDROP_MIN_SUPPORTED_MAJOR = 26;
constexpr int NEXTCLOUD_SERVER_VERSION_SECURE_FILEDROP_MIN_SUPPORTED_MINOR = 0;
constexpr int NEXTCLOUD_SERVER_VERSION_SECURE_FILEDROP_MIN_SUPPORTED_PATCH = 0;

constexpr int NEXTCLOUD_SERVER_VERSION_MOUNT_ROOT_PROPERTY_SUPPORTED_MAJOR = 28;
constexpr int NEXTCLOUD_SERVER_VERSION_MOUNT_ROOT_PROPERTY_SUPPORTED_MINOR = 0;
constexpr int NEXTCLOUD_SERVER_VERSION_MOUNT_ROOT_PROPERTY_SUPPORTED_PATCH = 3;

#endif // VERSION_H
