/****************************************************************************
** Meta object code from reading C++ file 'governancelabelslistmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../nextcloud-client/src/gui/governance/governancelabelslistmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'governancelabelslistmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3OCC25GovernanceLabelsListModelE_t {};
} // unnamed namespace

template <> constexpr inline auto OCC::GovernanceLabelsListModel::qt_create_metaobjectdata<qt_meta_tag_ZN3OCC25GovernanceLabelsListModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OCC::GovernanceLabelsListModel",
        "QML.Element",
        "auto",
        "accountChanged",
        "",
        "apiVersionChanged",
        "entityTypeChanged",
        "labelTypeChanged",
        "entityIdChanged",
        "refreshAvailableLabelsData",
        "OCC::Governance::LabelType",
        "labelType",
        "entityId",
        "labelBehaviorChanged",
        "displayError",
        "errorMessage",
        "busyChanged",
        "isEmptyChanged",
        "hasPendingChangesChanged",
        "setAvailableLabelsJsonData",
        "QJsonDocument",
        "reply",
        "toggleLabel",
        "row",
        "etagChanged",
        "labelsWereModified",
        "reset",
        "apply",
        "account",
        "AccountPtr",
        "apiVersion",
        "Governance::ApiVersion",
        "entityType",
        "Governance::EntityType",
        "Governance::LabelType",
        "labelBehavior",
        "LabelBehavior",
        "busy",
        "isEmpty",
        "hasPendingChanges",
        "LabelsListModelRoles",
        "IdRole",
        "NameRole",
        "PriorityRole",
        "DescriptionRole",
        "ColorRole",
        "SelectedRole",
        "UniqueLabel",
        "MultipleLabels",
        "UnknownLabelbehavior"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'accountChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'apiVersionChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'entityTypeChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'labelTypeChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'entityIdChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'refreshAvailableLabelsData'
        QtMocHelpers::SignalData<void(OCC::Governance::LabelType, const QString &)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { QMetaType::QString, 12 },
        }}),
        // Signal 'labelBehaviorChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'displayError'
        QtMocHelpers::SignalData<void(const QString &)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Signal 'busyChanged'
        QtMocHelpers::SignalData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isEmptyChanged'
        QtMocHelpers::SignalData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hasPendingChangesChanged'
        QtMocHelpers::SignalData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setAvailableLabelsJsonData'
        QtMocHelpers::SlotData<void(const QJsonDocument &)>(19, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'toggleLabel'
        QtMocHelpers::SlotData<void(int)>(22, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
        // Slot 'etagChanged'
        QtMocHelpers::SlotData<void()>(24, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'labelsWereModified'
        QtMocHelpers::SlotData<void()>(25, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reset'
        QtMocHelpers::SlotData<void()>(26, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'apply'
        QtMocHelpers::SlotData<void()>(27, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'account'
        QtMocHelpers::PropertyData<AccountPtr>(28, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 0),
        // property 'apiVersion'
        QtMocHelpers::PropertyData<Governance::ApiVersion>(30, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 1),
        // property 'entityType'
        QtMocHelpers::PropertyData<Governance::EntityType>(32, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 2),
        // property 'labelType'
        QtMocHelpers::PropertyData<Governance::LabelType>(11, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 3),
        // property 'entityId'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 4),
        // property 'labelBehavior'
        QtMocHelpers::PropertyData<enum LabelBehavior>(35, 0x80000000 | 36, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 6),
        // property 'busy'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 8),
        // property 'isEmpty'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 9),
        // property 'hasPendingChanges'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 10),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'LabelsListModelRoles'
        QtMocHelpers::EnumData<enum LabelsListModelRoles>(40, 40, QMC::EnumIsScoped).add({
            {   41, LabelsListModelRoles::IdRole },
            {   42, LabelsListModelRoles::NameRole },
            {   43, LabelsListModelRoles::PriorityRole },
            {   44, LabelsListModelRoles::DescriptionRole },
            {   45, LabelsListModelRoles::ColorRole },
            {   46, LabelsListModelRoles::SelectedRole },
        }),
        // enum 'LabelBehavior'
        QtMocHelpers::EnumData<enum LabelBehavior>(36, 36, QMC::EnumIsScoped).add({
            {   47, LabelBehavior::UniqueLabel },
            {   48, LabelBehavior::MultipleLabels },
            {   49, LabelBehavior::UnknownLabelbehavior },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<GovernanceLabelsListModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN3OCC25GovernanceLabelsListModelE[] = {
    QMetaObject::SuperData::link<OCC::Governance::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject OCC::GovernanceLabelsListModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3OCC25GovernanceLabelsListModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3OCC25GovernanceLabelsListModelE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN3OCC25GovernanceLabelsListModelE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3OCC25GovernanceLabelsListModelE_t>.metaTypes,
    nullptr
} };

void OCC::GovernanceLabelsListModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GovernanceLabelsListModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->accountChanged(); break;
        case 1: _t->apiVersionChanged(); break;
        case 2: _t->entityTypeChanged(); break;
        case 3: _t->labelTypeChanged(); break;
        case 4: _t->entityIdChanged(); break;
        case 5: _t->refreshAvailableLabelsData((*reinterpret_cast<std::add_pointer_t<OCC::Governance::LabelType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->labelBehaviorChanged(); break;
        case 7: _t->displayError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->busyChanged(); break;
        case 9: _t->isEmptyChanged(); break;
        case 10: _t->hasPendingChangesChanged(); break;
        case 11: _t->setAvailableLabelsJsonData((*reinterpret_cast<std::add_pointer_t<QJsonDocument>>(_a[1]))); break;
        case 12: _t->toggleLabel((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->etagChanged(); break;
        case 14: _t->labelsWereModified(); break;
        case 15: _t->reset(); break;
        case 16: _t->apply(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GovernanceLabelsListModel::*)()>(_a, &GovernanceLabelsListModel::accountChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (GovernanceLabelsListModel::*)()>(_a, &GovernanceLabelsListModel::apiVersionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (GovernanceLabelsListModel::*)()>(_a, &GovernanceLabelsListModel::entityTypeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (GovernanceLabelsListModel::*)()>(_a, &GovernanceLabelsListModel::labelTypeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (GovernanceLabelsListModel::*)()>(_a, &GovernanceLabelsListModel::entityIdChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (GovernanceLabelsListModel::*)(OCC::Governance::LabelType , const QString & )>(_a, &GovernanceLabelsListModel::refreshAvailableLabelsData, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (GovernanceLabelsListModel::*)()>(_a, &GovernanceLabelsListModel::labelBehaviorChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (GovernanceLabelsListModel::*)(const QString & )>(_a, &GovernanceLabelsListModel::displayError, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (GovernanceLabelsListModel::*)()>(_a, &GovernanceLabelsListModel::busyChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (GovernanceLabelsListModel::*)()>(_a, &GovernanceLabelsListModel::isEmptyChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (GovernanceLabelsListModel::*)()>(_a, &GovernanceLabelsListModel::hasPendingChangesChanged, 10))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<AccountPtr*>(_v) = _t->account(); break;
        case 1: *reinterpret_cast<Governance::ApiVersion*>(_v) = _t->apiVersion(); break;
        case 2: *reinterpret_cast<Governance::EntityType*>(_v) = _t->entityType(); break;
        case 3: *reinterpret_cast<Governance::LabelType*>(_v) = _t->labelType(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->entityId(); break;
        case 5: *reinterpret_cast<enum LabelBehavior*>(_v) = _t->labelBehavior(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->busy(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isEmpty(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->hasPendingChanges(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAccount(*reinterpret_cast<AccountPtr*>(_v)); break;
        case 1: _t->setApiVersion(*reinterpret_cast<Governance::ApiVersion*>(_v)); break;
        case 2: _t->setEntityType(*reinterpret_cast<Governance::EntityType*>(_v)); break;
        case 3: _t->setLabelType(*reinterpret_cast<Governance::LabelType*>(_v)); break;
        case 4: _t->setEntityId(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setLabelBehavior(*reinterpret_cast<enum LabelBehavior*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *OCC::GovernanceLabelsListModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OCC::GovernanceLabelsListModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3OCC25GovernanceLabelsListModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int OCC::GovernanceLabelsListModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void OCC::GovernanceLabelsListModel::accountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void OCC::GovernanceLabelsListModel::apiVersionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void OCC::GovernanceLabelsListModel::entityTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void OCC::GovernanceLabelsListModel::labelTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void OCC::GovernanceLabelsListModel::entityIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void OCC::GovernanceLabelsListModel::refreshAvailableLabelsData(OCC::Governance::LabelType _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void OCC::GovernanceLabelsListModel::labelBehaviorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void OCC::GovernanceLabelsListModel::displayError(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void OCC::GovernanceLabelsListModel::busyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void OCC::GovernanceLabelsListModel::isEmptyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void OCC::GovernanceLabelsListModel::hasPendingChangesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
