/****************************************************************************
** Meta object code from reading C++ file 'folderwatcher.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../nextcloud-client/src/gui/folderwatcher.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QSet>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'folderwatcher.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3OCC13FolderWatcherE_t {};
} // unnamed namespace

template <> constexpr inline auto OCC::FolderWatcher::qt_create_metaobjectdata<qt_meta_tag_ZN3OCC13FolderWatcherE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OCC::FolderWatcher",
        "pathChanged",
        "",
        "path",
        "filesLockReleased",
        "QSet<QString>",
        "files",
        "filesLockImposed",
        "lockedFilesFound",
        "lostChanges",
        "becameUnreliable",
        "message",
        "changeDetected",
        "paths",
        "folderAccountCapabilitiesChanged",
        "startNotificationTestWhenReady",
        "lockChangeDebouncingTimerTimedOut"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'pathChanged'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'filesLockReleased'
        QtMocHelpers::SignalData<void(const QSet<QString> &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'filesLockImposed'
        QtMocHelpers::SignalData<void(const QSet<QString> &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'lockedFilesFound'
        QtMocHelpers::SignalData<void(const QSet<QString> &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'lostChanges'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'becameUnreliable'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'changeDetected'
        QtMocHelpers::SlotData<void(const QString &)>(12, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'changeDetected'
        QtMocHelpers::SlotData<void(const QStringList &)>(12, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QStringList, 13 },
        }}),
        // Slot 'folderAccountCapabilitiesChanged'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'startNotificationTestWhenReady'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'lockChangeDebouncingTimerTimedOut'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FolderWatcher, qt_meta_tag_ZN3OCC13FolderWatcherE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OCC::FolderWatcher::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3OCC13FolderWatcherE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3OCC13FolderWatcherE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3OCC13FolderWatcherE_t>.metaTypes,
    nullptr
} };

void OCC::FolderWatcher::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FolderWatcher *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->pathChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->filesLockReleased((*reinterpret_cast<std::add_pointer_t<QSet<QString>>>(_a[1]))); break;
        case 2: _t->filesLockImposed((*reinterpret_cast<std::add_pointer_t<QSet<QString>>>(_a[1]))); break;
        case 3: _t->lockedFilesFound((*reinterpret_cast<std::add_pointer_t<QSet<QString>>>(_a[1]))); break;
        case 4: _t->lostChanges(); break;
        case 5: _t->becameUnreliable((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->changeDetected((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->changeDetected((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 8: _t->folderAccountCapabilitiesChanged(); break;
        case 9: _t->startNotificationTestWhenReady(); break;
        case 10: _t->lockChangeDebouncingTimerTimedOut(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSet<QString> >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSet<QString> >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSet<QString> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FolderWatcher::*)(const QString & )>(_a, &FolderWatcher::pathChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderWatcher::*)(const QSet<QString> & )>(_a, &FolderWatcher::filesLockReleased, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderWatcher::*)(const QSet<QString> & )>(_a, &FolderWatcher::filesLockImposed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderWatcher::*)(const QSet<QString> & )>(_a, &FolderWatcher::lockedFilesFound, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderWatcher::*)()>(_a, &FolderWatcher::lostChanges, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderWatcher::*)(const QString & )>(_a, &FolderWatcher::becameUnreliable, 5))
            return;
    }
}

const QMetaObject *OCC::FolderWatcher::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OCC::FolderWatcher::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3OCC13FolderWatcherE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int OCC::FolderWatcher::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void OCC::FolderWatcher::pathChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void OCC::FolderWatcher::filesLockReleased(const QSet<QString> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void OCC::FolderWatcher::filesLockImposed(const QSet<QString> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void OCC::FolderWatcher::lockedFilesFound(const QSet<QString> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void OCC::FolderWatcher::lostChanges()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void OCC::FolderWatcher::becameUnreliable(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
