/****************************************************************************
** Meta object code from reading C++ file 'accountwizardcontroller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../nextcloud-client/src/gui/wizard/accountwizardcontroller.h"
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'accountwizardcontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3OCC23AccountWizardControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto OCC::AccountWizardController::qt_create_metaobjectdata<qt_meta_tag_ZN3OCC23AccountWizardControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OCC::AccountWizardController",
        "currentStepChanged",
        "",
        "serverUrlChanged",
        "serverUrlEditableChanged",
        "overrideServerSelectionChanged",
        "busyChanged",
        "authPollingChanged",
        "errorTextChanged",
        "loginUrlChanged",
        "authStatusTextChanged",
        "userDisplayNameChanged",
        "serverDisplayNameChanged",
        "avatarUrlChanged",
        "syncEverythingDescriptionChanged",
        "localSyncFolderChanged",
        "localSyncFolderErrorChanged",
        "localSyncFolderFreeSpaceChanged",
        "localSyncFolderRequiredChanged",
        "syncModeChanged",
        "canFinishChanged",
        "needsSyncOptionsChanged",
        "askBeforeLargeFoldersChanged",
        "largeFolderThresholdMbChanged",
        "askBeforeExternalStorageChanged",
        "proxySettingsChanged",
        "basicAuthChanged",
        "publicShareSetupChanged",
        "finished",
        "result",
        "advancedOptionsRequested",
        "proxySettingsRequested",
        "clientCertificateDialogRequested",
        "secureConnectionFailed",
        "host",
        "retryHttpOnly",
        "clientCertificateChanged",
        "slotSystemProxyLookupDone",
        "QNetworkProxy",
        "proxy",
        "slotFindServer",
        "slotFindServerBehindRedirect",
        "slotFoundServer",
        "QUrl",
        "url",
        "QJsonObject",
        "info",
        "slotNoServerFound",
        "QNetworkReply*",
        "reply",
        "slotNoServerFoundTimeout",
        "slotDetermineAuthType",
        "slotFlow2AuthResult",
        "OCC::Flow2Auth::Result",
        "errorString",
        "user",
        "appPassword",
        "slotFlow2StatusChanged",
        "OCC::Flow2Auth::PollStatus",
        "status",
        "secondsLeft",
        "slotAuthError",
        "slotRemoteFolderExists",
        "slotCreateRemoteFolderFinished",
        "submitServerUrl",
        "submitBasicAuth",
        "openBrowserLogin",
        "copyLoginLink",
        "openSignup",
        "openSelfHostedServerGuide",
        "openProxySettings",
        "cancel",
        "goBack",
        "finish",
        "skipFolderConfiguration",
        "setSyncMode",
        "syncMode",
        "chooseLocalSyncFolder",
        "openSelectiveSync",
        "openAdvancedOptions",
        "setAskBeforeLargeFolders",
        "ask",
        "setLargeFolderThresholdMb",
        "thresholdMb",
        "setAskBeforeExternalStorage",
        "pollNow",
        "chooseClientCertificate",
        "submitClientCertificate",
        "clearClientCertificateInput",
        "retrySecureConnectionWithoutTls",
        "useClientCertificateForSecureConnection",
        "currentStep",
        "Step",
        "serverUrl",
        "serverUrlEditable",
        "overrideServerSelectionRequired",
        "startLoginFlowAutomatically",
        "overrideServerNames",
        "overrideServerIndex",
        "busy",
        "authPolling",
        "errorText",
        "loginUrl",
        "authStatusText",
        "userDisplayName",
        "serverDisplayName",
        "avatarUrl",
        "syncEverythingDescription",
        "localSyncFolder",
        "localSyncFolderDisplay",
        "localSyncFolderError",
        "localSyncFolderFreeSpace",
        "localSyncFolderRequired",
        "SyncMode",
        "canFinish",
        "canUseVirtualFiles",
        "isUsingFileProvider",
        "canUseClassicSync",
        "needsSyncOptions",
        "canSkipFolderConfiguration",
        "hasAdvancedOptions",
        "showLargeFolderConfirmation",
        "askBeforeLargeFolders",
        "largeFolderThresholdMb",
        "showExternalStorageConfirmation",
        "askBeforeExternalStorage",
        "proxySettingsAvailable",
        "proxyMode",
        "manualProxyType",
        "proxyHost",
        "proxyPort",
        "proxyAuthenticationRequired",
        "proxyUser",
        "proxyPassword",
        "proxySettingsValid",
        "showProxyLocalhostWarning",
        "basicAuthUser",
        "basicAuthPassword",
        "basicAuthValid",
        "publicShareSetup",
        "appName",
        "serverUrlPlaceholder",
        "clientCertificatePath",
        "clientCertificatePassword",
        "clientCertificateError",
        "clientCertificateValid",
        "ServerStep",
        "BrowserAuthStep",
        "BasicAuthStep",
        "SyncOptionsStep",
        "CompletedStep",
        "SyncEverything",
        "SelectiveSync",
        "VirtualFiles"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentStepChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'serverUrlChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'serverUrlEditableChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'overrideServerSelectionChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'busyChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'authPollingChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorTextChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loginUrlChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'authStatusTextChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'userDisplayNameChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'serverDisplayNameChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'avatarUrlChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'syncEverythingDescriptionChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'localSyncFolderChanged'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'localSyncFolderErrorChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'localSyncFolderFreeSpaceChanged'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'localSyncFolderRequiredChanged'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'syncModeChanged'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canFinishChanged'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'needsSyncOptionsChanged'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'askBeforeLargeFoldersChanged'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'largeFolderThresholdMbChanged'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'askBeforeExternalStorageChanged'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'proxySettingsChanged'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'basicAuthChanged'
        QtMocHelpers::SignalData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'publicShareSetupChanged'
        QtMocHelpers::SignalData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'finished'
        QtMocHelpers::SignalData<void(int)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 29 },
        }}),
        // Signal 'advancedOptionsRequested'
        QtMocHelpers::SignalData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'proxySettingsRequested'
        QtMocHelpers::SignalData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clientCertificateDialogRequested'
        QtMocHelpers::SignalData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'secureConnectionFailed'
        QtMocHelpers::SignalData<void(const QString &, bool)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 34 }, { QMetaType::Bool, 35 },
        }}),
        // Signal 'clientCertificateChanged'
        QtMocHelpers::SignalData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSystemProxyLookupDone'
        QtMocHelpers::SlotData<void(const QNetworkProxy &)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 38, 39 },
        }}),
        // Slot 'slotFindServer'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotFindServerBehindRedirect'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotFoundServer'
        QtMocHelpers::SlotData<void(const QUrl &, const QJsonObject &)>(42, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 43, 44 }, { 0x80000000 | 45, 46 },
        }}),
        // Slot 'slotNoServerFound'
        QtMocHelpers::SlotData<void(QNetworkReply *)>(47, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 48, 49 },
        }}),
        // Slot 'slotNoServerFoundTimeout'
        QtMocHelpers::SlotData<void(const QUrl &)>(50, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 43, 44 },
        }}),
        // Slot 'slotDetermineAuthType'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotFlow2AuthResult'
        QtMocHelpers::SlotData<void(OCC::Flow2Auth::Result, const QString &, const QString &, const QString &)>(52, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 53, 29 }, { QMetaType::QString, 54 }, { QMetaType::QString, 55 }, { QMetaType::QString, 56 },
        }}),
        // Slot 'slotFlow2StatusChanged'
        QtMocHelpers::SlotData<void(OCC::Flow2Auth::PollStatus, int)>(57, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 58, 59 }, { QMetaType::Int, 60 },
        }}),
        // Slot 'slotAuthError'
        QtMocHelpers::SlotData<void(QNetworkReply *)>(61, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 48, 49 },
        }}),
        // Slot 'slotRemoteFolderExists'
        QtMocHelpers::SlotData<void(QNetworkReply *)>(62, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 48, 49 },
        }}),
        // Slot 'slotCreateRemoteFolderFinished'
        QtMocHelpers::SlotData<void(QNetworkReply *)>(63, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 48, 49 },
        }}),
        // Method 'submitServerUrl'
        QtMocHelpers::MethodData<void()>(64, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'submitBasicAuth'
        QtMocHelpers::MethodData<void()>(65, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'openBrowserLogin'
        QtMocHelpers::MethodData<void()>(66, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'copyLoginLink'
        QtMocHelpers::MethodData<void()>(67, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'openSignup'
        QtMocHelpers::MethodData<void()>(68, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'openSelfHostedServerGuide'
        QtMocHelpers::MethodData<void()>(69, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'openProxySettings'
        QtMocHelpers::MethodData<void()>(70, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'cancel'
        QtMocHelpers::MethodData<void()>(71, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'goBack'
        QtMocHelpers::MethodData<void()>(72, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'finish'
        QtMocHelpers::MethodData<void()>(73, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'skipFolderConfiguration'
        QtMocHelpers::MethodData<void()>(74, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'setSyncMode'
        QtMocHelpers::MethodData<void(int)>(75, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 76 },
        }}),
        // Method 'chooseLocalSyncFolder'
        QtMocHelpers::MethodData<void()>(77, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'openSelectiveSync'
        QtMocHelpers::MethodData<void()>(78, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'openAdvancedOptions'
        QtMocHelpers::MethodData<void()>(79, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'setAskBeforeLargeFolders'
        QtMocHelpers::MethodData<void(bool)>(80, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 81 },
        }}),
        // Method 'setLargeFolderThresholdMb'
        QtMocHelpers::MethodData<void(int)>(82, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 83 },
        }}),
        // Method 'setAskBeforeExternalStorage'
        QtMocHelpers::MethodData<void(bool)>(84, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 81 },
        }}),
        // Method 'pollNow'
        QtMocHelpers::MethodData<void()>(85, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'chooseClientCertificate'
        QtMocHelpers::MethodData<void()>(86, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'submitClientCertificate'
        QtMocHelpers::MethodData<bool()>(87, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'clearClientCertificateInput'
        QtMocHelpers::MethodData<void()>(88, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'retrySecureConnectionWithoutTls'
        QtMocHelpers::MethodData<void()>(89, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'useClientCertificateForSecureConnection'
        QtMocHelpers::MethodData<void()>(90, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'currentStep'
        QtMocHelpers::PropertyData<enum Step>(91, 0x80000000 | 92, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'serverUrl'
        QtMocHelpers::PropertyData<QString>(93, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'serverUrlEditable'
        QtMocHelpers::PropertyData<bool>(94, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'overrideServerSelectionRequired'
        QtMocHelpers::PropertyData<bool>(95, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'startLoginFlowAutomatically'
        QtMocHelpers::PropertyData<bool>(96, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'overrideServerNames'
        QtMocHelpers::PropertyData<QStringList>(97, QMetaType::QStringList, QMC::DefaultPropertyFlags, 3),
        // property 'overrideServerIndex'
        QtMocHelpers::PropertyData<int>(98, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'busy'
        QtMocHelpers::PropertyData<bool>(99, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
        // property 'authPolling'
        QtMocHelpers::PropertyData<bool>(100, QMetaType::Bool, QMC::DefaultPropertyFlags, 5),
        // property 'errorText'
        QtMocHelpers::PropertyData<QString>(101, QMetaType::QString, QMC::DefaultPropertyFlags, 6),
        // property 'loginUrl'
        QtMocHelpers::PropertyData<QUrl>(102, 0x80000000 | 43, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 7),
        // property 'authStatusText'
        QtMocHelpers::PropertyData<QString>(103, QMetaType::QString, QMC::DefaultPropertyFlags, 8),
        // property 'userDisplayName'
        QtMocHelpers::PropertyData<QString>(104, QMetaType::QString, QMC::DefaultPropertyFlags, 9),
        // property 'serverDisplayName'
        QtMocHelpers::PropertyData<QString>(105, QMetaType::QString, QMC::DefaultPropertyFlags, 10),
        // property 'avatarUrl'
        QtMocHelpers::PropertyData<QString>(106, QMetaType::QString, QMC::DefaultPropertyFlags, 11),
        // property 'syncEverythingDescription'
        QtMocHelpers::PropertyData<QString>(107, QMetaType::QString, QMC::DefaultPropertyFlags, 12),
        // property 'localSyncFolder'
        QtMocHelpers::PropertyData<QString>(108, QMetaType::QString, QMC::DefaultPropertyFlags, 13),
        // property 'localSyncFolderDisplay'
        QtMocHelpers::PropertyData<QString>(109, QMetaType::QString, QMC::DefaultPropertyFlags, 13),
        // property 'localSyncFolderError'
        QtMocHelpers::PropertyData<QString>(110, QMetaType::QString, QMC::DefaultPropertyFlags, 14),
        // property 'localSyncFolderFreeSpace'
        QtMocHelpers::PropertyData<QString>(111, QMetaType::QString, QMC::DefaultPropertyFlags, 15),
        // property 'localSyncFolderRequired'
        QtMocHelpers::PropertyData<bool>(112, QMetaType::Bool, QMC::DefaultPropertyFlags, 16),
        // property 'syncMode'
        QtMocHelpers::PropertyData<enum SyncMode>(76, 0x80000000 | 113, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 17),
        // property 'canFinish'
        QtMocHelpers::PropertyData<bool>(114, QMetaType::Bool, QMC::DefaultPropertyFlags, 18),
        // property 'canUseVirtualFiles'
        QtMocHelpers::PropertyData<bool>(115, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'isUsingFileProvider'
        QtMocHelpers::PropertyData<bool>(116, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'canUseClassicSync'
        QtMocHelpers::PropertyData<bool>(117, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'needsSyncOptions'
        QtMocHelpers::PropertyData<bool>(118, QMetaType::Bool, QMC::DefaultPropertyFlags, 19),
        // property 'canSkipFolderConfiguration'
        QtMocHelpers::PropertyData<bool>(119, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hasAdvancedOptions'
        QtMocHelpers::PropertyData<bool>(120, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showLargeFolderConfirmation'
        QtMocHelpers::PropertyData<bool>(121, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'askBeforeLargeFolders'
        QtMocHelpers::PropertyData<bool>(122, QMetaType::Bool, QMC::DefaultPropertyFlags, 20),
        // property 'largeFolderThresholdMb'
        QtMocHelpers::PropertyData<int>(123, QMetaType::Int, QMC::DefaultPropertyFlags, 21),
        // property 'showExternalStorageConfirmation'
        QtMocHelpers::PropertyData<bool>(124, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'askBeforeExternalStorage'
        QtMocHelpers::PropertyData<bool>(125, QMetaType::Bool, QMC::DefaultPropertyFlags, 22),
        // property 'proxySettingsAvailable'
        QtMocHelpers::PropertyData<bool>(126, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'proxyMode'
        QtMocHelpers::PropertyData<int>(127, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 23),
        // property 'manualProxyType'
        QtMocHelpers::PropertyData<int>(128, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 23),
        // property 'proxyHost'
        QtMocHelpers::PropertyData<QString>(129, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 23),
        // property 'proxyPort'
        QtMocHelpers::PropertyData<int>(130, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 23),
        // property 'proxyAuthenticationRequired'
        QtMocHelpers::PropertyData<bool>(131, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 23),
        // property 'proxyUser'
        QtMocHelpers::PropertyData<QString>(132, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 23),
        // property 'proxyPassword'
        QtMocHelpers::PropertyData<QString>(133, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 23),
        // property 'proxySettingsValid'
        QtMocHelpers::PropertyData<bool>(134, QMetaType::Bool, QMC::DefaultPropertyFlags, 23),
        // property 'showProxyLocalhostWarning'
        QtMocHelpers::PropertyData<bool>(135, QMetaType::Bool, QMC::DefaultPropertyFlags, 23),
        // property 'basicAuthUser'
        QtMocHelpers::PropertyData<QString>(136, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 24),
        // property 'basicAuthPassword'
        QtMocHelpers::PropertyData<QString>(137, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 24),
        // property 'basicAuthValid'
        QtMocHelpers::PropertyData<bool>(138, QMetaType::Bool, QMC::DefaultPropertyFlags, 24),
        // property 'publicShareSetup'
        QtMocHelpers::PropertyData<bool>(139, QMetaType::Bool, QMC::DefaultPropertyFlags, 25),
        // property 'appName'
        QtMocHelpers::PropertyData<QString>(140, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'serverUrlPlaceholder'
        QtMocHelpers::PropertyData<QString>(141, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'clientCertificatePath'
        QtMocHelpers::PropertyData<QString>(142, QMetaType::QString, QMC::DefaultPropertyFlags, 31),
        // property 'clientCertificatePassword'
        QtMocHelpers::PropertyData<QString>(143, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 31),
        // property 'clientCertificateError'
        QtMocHelpers::PropertyData<QString>(144, QMetaType::QString, QMC::DefaultPropertyFlags, 31),
        // property 'clientCertificateValid'
        QtMocHelpers::PropertyData<bool>(145, QMetaType::Bool, QMC::DefaultPropertyFlags, 31),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Step'
        QtMocHelpers::EnumData<enum Step>(92, 92, QMC::EnumFlags{}).add({
            {  146, Step::ServerStep },
            {  147, Step::BrowserAuthStep },
            {  148, Step::BasicAuthStep },
            {  149, Step::SyncOptionsStep },
            {  150, Step::CompletedStep },
        }),
        // enum 'SyncMode'
        QtMocHelpers::EnumData<enum SyncMode>(113, 113, QMC::EnumFlags{}).add({
            {  151, SyncMode::SyncEverything },
            {  152, SyncMode::SelectiveSync },
            {  153, SyncMode::VirtualFiles },
        }),
    };
    return QtMocHelpers::metaObjectData<AccountWizardController, qt_meta_tag_ZN3OCC23AccountWizardControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OCC::AccountWizardController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3OCC23AccountWizardControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3OCC23AccountWizardControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3OCC23AccountWizardControllerE_t>.metaTypes,
    nullptr
} };

void OCC::AccountWizardController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AccountWizardController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentStepChanged(); break;
        case 1: _t->serverUrlChanged(); break;
        case 2: _t->serverUrlEditableChanged(); break;
        case 3: _t->overrideServerSelectionChanged(); break;
        case 4: _t->busyChanged(); break;
        case 5: _t->authPollingChanged(); break;
        case 6: _t->errorTextChanged(); break;
        case 7: _t->loginUrlChanged(); break;
        case 8: _t->authStatusTextChanged(); break;
        case 9: _t->userDisplayNameChanged(); break;
        case 10: _t->serverDisplayNameChanged(); break;
        case 11: _t->avatarUrlChanged(); break;
        case 12: _t->syncEverythingDescriptionChanged(); break;
        case 13: _t->localSyncFolderChanged(); break;
        case 14: _t->localSyncFolderErrorChanged(); break;
        case 15: _t->localSyncFolderFreeSpaceChanged(); break;
        case 16: _t->localSyncFolderRequiredChanged(); break;
        case 17: _t->syncModeChanged(); break;
        case 18: _t->canFinishChanged(); break;
        case 19: _t->needsSyncOptionsChanged(); break;
        case 20: _t->askBeforeLargeFoldersChanged(); break;
        case 21: _t->largeFolderThresholdMbChanged(); break;
        case 22: _t->askBeforeExternalStorageChanged(); break;
        case 23: _t->proxySettingsChanged(); break;
        case 24: _t->basicAuthChanged(); break;
        case 25: _t->publicShareSetupChanged(); break;
        case 26: _t->finished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 27: _t->advancedOptionsRequested(); break;
        case 28: _t->proxySettingsRequested(); break;
        case 29: _t->clientCertificateDialogRequested(); break;
        case 30: _t->secureConnectionFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 31: _t->clientCertificateChanged(); break;
        case 32: _t->slotSystemProxyLookupDone((*reinterpret_cast<std::add_pointer_t<QNetworkProxy>>(_a[1]))); break;
        case 33: _t->slotFindServer(); break;
        case 34: _t->slotFindServerBehindRedirect(); break;
        case 35: _t->slotFoundServer((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QJsonObject>>(_a[2]))); break;
        case 36: _t->slotNoServerFound((*reinterpret_cast<std::add_pointer_t<QNetworkReply*>>(_a[1]))); break;
        case 37: _t->slotNoServerFoundTimeout((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 38: _t->slotDetermineAuthType(); break;
        case 39: _t->slotFlow2AuthResult((*reinterpret_cast<std::add_pointer_t<OCC::Flow2Auth::Result>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 40: _t->slotFlow2StatusChanged((*reinterpret_cast<std::add_pointer_t<OCC::Flow2Auth::PollStatus>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 41: _t->slotAuthError((*reinterpret_cast<std::add_pointer_t<QNetworkReply*>>(_a[1]))); break;
        case 42: _t->slotRemoteFolderExists((*reinterpret_cast<std::add_pointer_t<QNetworkReply*>>(_a[1]))); break;
        case 43: _t->slotCreateRemoteFolderFinished((*reinterpret_cast<std::add_pointer_t<QNetworkReply*>>(_a[1]))); break;
        case 44: _t->submitServerUrl(); break;
        case 45: _t->submitBasicAuth(); break;
        case 46: _t->openBrowserLogin(); break;
        case 47: _t->copyLoginLink(); break;
        case 48: _t->openSignup(); break;
        case 49: _t->openSelfHostedServerGuide(); break;
        case 50: _t->openProxySettings(); break;
        case 51: _t->cancel(); break;
        case 52: _t->goBack(); break;
        case 53: _t->finish(); break;
        case 54: _t->skipFolderConfiguration(); break;
        case 55: _t->setSyncMode((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 56: _t->chooseLocalSyncFolder(); break;
        case 57: _t->openSelectiveSync(); break;
        case 58: _t->openAdvancedOptions(); break;
        case 59: _t->setAskBeforeLargeFolders((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 60: _t->setLargeFolderThresholdMb((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 61: _t->setAskBeforeExternalStorage((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 62: _t->pollNow(); break;
        case 63: _t->chooseClientCertificate(); break;
        case 64: { bool _r = _t->submitClientCertificate();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 65: _t->clearClientCertificateInput(); break;
        case 66: _t->retrySecureConnectionWithoutTls(); break;
        case 67: _t->useClientCertificateForSecureConnection(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkProxy >(); break;
            }
            break;
        case 36:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply* >(); break;
            }
            break;
        case 41:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply* >(); break;
            }
            break;
        case 42:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply* >(); break;
            }
            break;
        case 43:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QNetworkReply* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AccountWizardController::*)()>(_a, &AccountWizardController::currentStepChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountWizardController::*)()>(_a, &AccountWizardController::serverUrlChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountWizardController::*)()>(_a, &AccountWizardController::serverUrlEditableChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountWizardController::*)()>(_a, &AccountWizardController::overrideServerSelectionChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountWizardController::*)()>(_a, &AccountWizardController::busyChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountWizardController::*)()>(_a, &AccountWizardController::authPollingChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountWizardController::*)()>(_a, &AccountWizardController::errorTextChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountWizardController::*)()>(_a, &AccountWizardController::loginUrlChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountWizardController::*)()>(_a, &AccountWizardController::authStatusTextChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountWizardController::*)()>(_a, &AccountWizardController::userDisplayNameChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountWizardController::*)()>(_a, &AccountWizardController::serverDisplayNameChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountWizardController::*)()>(_a, &AccountWizardController::avatarUrlChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountWizardController::*)()>(_a, &AccountWizardController::syncEverythingDescriptionChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountWizardController::*)()>(_a, &AccountWizardController::localSyncFolderChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountWizardController::*)()>(_a, &AccountWizardController::localSyncFolderErrorChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountWizardController::*)()>(_a, &AccountWizardController::localSyncFolderFreeSpaceChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountWizardController::*)()>(_a, &AccountWizardController::localSyncFolderRequiredChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountWizardController::*)()>(_a, &AccountWizardController::syncModeChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountWizardController::*)()>(_a, &AccountWizardController::canFinishChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountWizardController::*)()>(_a, &AccountWizardController::needsSyncOptionsChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountWizardController::*)()>(_a, &AccountWizardController::askBeforeLargeFoldersChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountWizardController::*)()>(_a, &AccountWizardController::largeFolderThresholdMbChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountWizardController::*)()>(_a, &AccountWizardController::askBeforeExternalStorageChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountWizardController::*)()>(_a, &AccountWizardController::proxySettingsChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountWizardController::*)()>(_a, &AccountWizardController::basicAuthChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountWizardController::*)()>(_a, &AccountWizardController::publicShareSetupChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountWizardController::*)(int )>(_a, &AccountWizardController::finished, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountWizardController::*)()>(_a, &AccountWizardController::advancedOptionsRequested, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountWizardController::*)()>(_a, &AccountWizardController::proxySettingsRequested, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountWizardController::*)()>(_a, &AccountWizardController::clientCertificateDialogRequested, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountWizardController::*)(const QString & , bool )>(_a, &AccountWizardController::secureConnectionFailed, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccountWizardController::*)()>(_a, &AccountWizardController::clientCertificateChanged, 31))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum Step*>(_v) = _t->currentStep(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->serverUrl(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->serverUrlEditable(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->overrideServerSelectionRequired(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->startLoginFlowAutomatically(); break;
        case 5: *reinterpret_cast<QStringList*>(_v) = _t->overrideServerNames(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->overrideServerIndex(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->busy(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->authPolling(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->errorText(); break;
        case 10: *reinterpret_cast<QUrl*>(_v) = _t->loginUrl(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->authStatusText(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->userDisplayName(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->serverDisplayName(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->avatarUrl(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->syncEverythingDescription(); break;
        case 16: *reinterpret_cast<QString*>(_v) = _t->localSyncFolder(); break;
        case 17: *reinterpret_cast<QString*>(_v) = _t->localSyncFolderDisplay(); break;
        case 18: *reinterpret_cast<QString*>(_v) = _t->localSyncFolderError(); break;
        case 19: *reinterpret_cast<QString*>(_v) = _t->localSyncFolderFreeSpace(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->localSyncFolderRequired(); break;
        case 21: *reinterpret_cast<enum SyncMode*>(_v) = _t->syncMode(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->canFinish(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->canUseVirtualFiles(); break;
        case 24: *reinterpret_cast<bool*>(_v) = _t->isUsingFileProvider(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->canUseClassicSync(); break;
        case 26: *reinterpret_cast<bool*>(_v) = _t->needsSyncOptions(); break;
        case 27: *reinterpret_cast<bool*>(_v) = _t->canSkipFolderConfiguration(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->hasAdvancedOptions(); break;
        case 29: *reinterpret_cast<bool*>(_v) = _t->showLargeFolderConfirmation(); break;
        case 30: *reinterpret_cast<bool*>(_v) = _t->askBeforeLargeFolders(); break;
        case 31: *reinterpret_cast<int*>(_v) = _t->largeFolderThresholdMb(); break;
        case 32: *reinterpret_cast<bool*>(_v) = _t->showExternalStorageConfirmation(); break;
        case 33: *reinterpret_cast<bool*>(_v) = _t->askBeforeExternalStorage(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->proxySettingsAvailable(); break;
        case 35: *reinterpret_cast<int*>(_v) = _t->proxyMode(); break;
        case 36: *reinterpret_cast<int*>(_v) = _t->manualProxyType(); break;
        case 37: *reinterpret_cast<QString*>(_v) = _t->proxyHost(); break;
        case 38: *reinterpret_cast<int*>(_v) = _t->proxyPort(); break;
        case 39: *reinterpret_cast<bool*>(_v) = _t->proxyAuthenticationRequired(); break;
        case 40: *reinterpret_cast<QString*>(_v) = _t->proxyUser(); break;
        case 41: *reinterpret_cast<QString*>(_v) = _t->proxyPassword(); break;
        case 42: *reinterpret_cast<bool*>(_v) = _t->proxySettingsValid(); break;
        case 43: *reinterpret_cast<bool*>(_v) = _t->showProxyLocalhostWarning(); break;
        case 44: *reinterpret_cast<QString*>(_v) = _t->basicAuthUser(); break;
        case 45: *reinterpret_cast<QString*>(_v) = _t->basicAuthPassword(); break;
        case 46: *reinterpret_cast<bool*>(_v) = _t->basicAuthValid(); break;
        case 47: *reinterpret_cast<bool*>(_v) = _t->publicShareSetup(); break;
        case 48: *reinterpret_cast<QString*>(_v) = _t->appName(); break;
        case 49: *reinterpret_cast<QString*>(_v) = _t->serverUrlPlaceholder(); break;
        case 50: *reinterpret_cast<QString*>(_v) = _t->clientCertificatePath(); break;
        case 51: *reinterpret_cast<QString*>(_v) = _t->clientCertificatePassword(); break;
        case 52: *reinterpret_cast<QString*>(_v) = _t->clientCertificateError(); break;
        case 53: *reinterpret_cast<bool*>(_v) = _t->clientCertificateValid(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setServerUrl(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setOverrideServerIndex(*reinterpret_cast<int*>(_v)); break;
        case 35: _t->setProxyMode(*reinterpret_cast<int*>(_v)); break;
        case 36: _t->setManualProxyType(*reinterpret_cast<int*>(_v)); break;
        case 37: _t->setProxyHost(*reinterpret_cast<QString*>(_v)); break;
        case 38: _t->setProxyPort(*reinterpret_cast<int*>(_v)); break;
        case 39: _t->setProxyAuthenticationRequired(*reinterpret_cast<bool*>(_v)); break;
        case 40: _t->setProxyUser(*reinterpret_cast<QString*>(_v)); break;
        case 41: _t->setProxyPassword(*reinterpret_cast<QString*>(_v)); break;
        case 44: _t->setBasicAuthUser(*reinterpret_cast<QString*>(_v)); break;
        case 45: _t->setBasicAuthPassword(*reinterpret_cast<QString*>(_v)); break;
        case 51: _t->setClientCertificatePassword(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *OCC::AccountWizardController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OCC::AccountWizardController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3OCC23AccountWizardControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int OCC::AccountWizardController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 68)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 68;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 68)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 68;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 54;
    }
    return _id;
}

// SIGNAL 0
void OCC::AccountWizardController::currentStepChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void OCC::AccountWizardController::serverUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void OCC::AccountWizardController::serverUrlEditableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void OCC::AccountWizardController::overrideServerSelectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void OCC::AccountWizardController::busyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void OCC::AccountWizardController::authPollingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void OCC::AccountWizardController::errorTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void OCC::AccountWizardController::loginUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void OCC::AccountWizardController::authStatusTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void OCC::AccountWizardController::userDisplayNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void OCC::AccountWizardController::serverDisplayNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void OCC::AccountWizardController::avatarUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void OCC::AccountWizardController::syncEverythingDescriptionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void OCC::AccountWizardController::localSyncFolderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void OCC::AccountWizardController::localSyncFolderErrorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void OCC::AccountWizardController::localSyncFolderFreeSpaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void OCC::AccountWizardController::localSyncFolderRequiredChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void OCC::AccountWizardController::syncModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void OCC::AccountWizardController::canFinishChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void OCC::AccountWizardController::needsSyncOptionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void OCC::AccountWizardController::askBeforeLargeFoldersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void OCC::AccountWizardController::largeFolderThresholdMbChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void OCC::AccountWizardController::askBeforeExternalStorageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void OCC::AccountWizardController::proxySettingsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void OCC::AccountWizardController::basicAuthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void OCC::AccountWizardController::publicShareSetupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void OCC::AccountWizardController::finished(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1);
}

// SIGNAL 27
void OCC::AccountWizardController::advancedOptionsRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void OCC::AccountWizardController::proxySettingsRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}

// SIGNAL 29
void OCC::AccountWizardController::clientCertificateDialogRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}

// SIGNAL 30
void OCC::AccountWizardController::secureConnectionFailed(const QString & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 30, nullptr, _t1, _t2);
}

// SIGNAL 31
void OCC::AccountWizardController::clientCertificateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 31, nullptr);
}
QT_WARNING_POP
