/********************************************************************************
** Form generated from reading UI file 'advancedsettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ADVANCEDSETTINGS_H
#define UI_ADVANCEDSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "settingsswitch.h"

namespace OCC {

class Ui_AdvancedSettings
{
public:
    QVBoxLayout *pageLayout;
    QGroupBox *advancedGroupBox;
    QVBoxLayout *largeFoldersLayout;
    QHBoxLayout *newFolderLimitRow;
    QLabel *newFolderLimitLabel;
    QSpinBox *newFolderLimitSpinBox;
    QLabel *label;
    QSpacerItem *newFolderLimitSpacer;
    OCC::SettingsSwitch *newFolderLimitCheckBox;
    QFrame *existingFolderLimitSeparator;
    QHBoxLayout *existingFolderLimitRow;
    QLabel *existingFolderLimitLabel;
    QSpacerItem *existingFolderLimitSpacer;
    OCC::SettingsSwitch *existingFolderLimitCheckBox;
    QFrame *stopExistingFolderNowBigSyncSeparator;
    QHBoxLayout *stopExistingFolderNowBigSyncRow;
    QLabel *stopExistingFolderNowBigSyncLabel;
    QSpacerItem *stopExistingFolderNowBigSyncSpacer;
    OCC::SettingsSwitch *stopExistingFolderNowBigSyncCheckBox;
    QFrame *remotePollIntervalSeparator;
    QWidget *horizontalLayoutWidget_remotePollInterval;
    QHBoxLayout *remotePollIntervalRow;
    QLabel *remotePollIntervalLabel;
    QSpinBox *remotePollIntervalSpinBox;
    QLabel *labelInterval;
    QSpacerItem *remotePollIntervalSpacer;
    QGroupBox *syncBehaviorGroupBox;
    QVBoxLayout *syncBehaviorLayout;
    QHBoxLayout *newExternalStorageRow;
    QLabel *newExternalStorageLabel;
    QSpacerItem *newExternalStorageSpacer;
    OCC::SettingsSwitch *newExternalStorage;
    QFrame *moveFilesToTrashSeparator;
    QHBoxLayout *moveFilesToTrashRow;
    QLabel *moveFilesToTrashLabel;
    QSpacerItem *moveFilesToTrashSpacer;
    OCC::SettingsSwitch *moveFilesToTrashCheckBox;
    QFrame *showInExplorerNavigationPaneSeparator;
    QWidget *showInExplorerNavigationPaneRowWidget;
    QHBoxLayout *showInExplorerNavigationPaneRow;
    QLabel *showInExplorerNavigationPaneLabel;
    QSpacerItem *showInExplorerNavigationPaneSpacer;
    OCC::SettingsSwitch *showInExplorerNavigationPaneCheckBox;
    QGroupBox *advancedActionsGroupBox;
    QHBoxLayout *advancedActionsLayout;
    QSpacerItem *advancedActionsSpacer;
    QPushButton *ignoredFilesButton;
    QPushButton *debugArchiveButton;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *OCC__AdvancedSettings)
    {
        if (OCC__AdvancedSettings->objectName().isEmpty())
            OCC__AdvancedSettings->setObjectName("OCC__AdvancedSettings");
        OCC__AdvancedSettings->resize(667, 360);
        OCC__AdvancedSettings->setWindowTitle(QString::fromUtf8("Form"));
        pageLayout = new QVBoxLayout(OCC__AdvancedSettings);
        pageLayout->setSpacing(12);
        pageLayout->setObjectName("pageLayout");
        pageLayout->setContentsMargins(0, 0, 0, 0);
        advancedGroupBox = new QGroupBox(OCC__AdvancedSettings);
        advancedGroupBox->setObjectName("advancedGroupBox");
        largeFoldersLayout = new QVBoxLayout(advancedGroupBox);
        largeFoldersLayout->setSpacing(0);
        largeFoldersLayout->setObjectName("largeFoldersLayout");
        newFolderLimitRow = new QHBoxLayout();
        newFolderLimitRow->setObjectName("newFolderLimitRow");
        newFolderLimitLabel = new QLabel(advancedGroupBox);
        newFolderLimitLabel->setObjectName("newFolderLimitLabel");

        newFolderLimitRow->addWidget(newFolderLimitLabel);

        newFolderLimitSpinBox = new QSpinBox(advancedGroupBox);
        newFolderLimitSpinBox->setObjectName("newFolderLimitSpinBox");
        newFolderLimitSpinBox->setMaximum(999999);
        newFolderLimitSpinBox->setValue(99);

        newFolderLimitRow->addWidget(newFolderLimitSpinBox);

        label = new QLabel(advancedGroupBox);
        label->setObjectName("label");

        newFolderLimitRow->addWidget(label);

        newFolderLimitSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        newFolderLimitRow->addItem(newFolderLimitSpacer);

        newFolderLimitCheckBox = new OCC::SettingsSwitch(advancedGroupBox);
        newFolderLimitCheckBox->setObjectName("newFolderLimitCheckBox");
        newFolderLimitCheckBox->setChecked(true);

        newFolderLimitRow->addWidget(newFolderLimitCheckBox);


        largeFoldersLayout->addLayout(newFolderLimitRow);

        existingFolderLimitSeparator = new QFrame(advancedGroupBox);
        existingFolderLimitSeparator->setObjectName("existingFolderLimitSeparator");
        existingFolderLimitSeparator->setFrameShape(QFrame::Shape::HLine);
        existingFolderLimitSeparator->setFrameShadow(QFrame::Shadow::Plain);

        largeFoldersLayout->addWidget(existingFolderLimitSeparator);

        existingFolderLimitRow = new QHBoxLayout();
        existingFolderLimitRow->setObjectName("existingFolderLimitRow");
        existingFolderLimitLabel = new QLabel(advancedGroupBox);
        existingFolderLimitLabel->setObjectName("existingFolderLimitLabel");

        existingFolderLimitRow->addWidget(existingFolderLimitLabel);

        existingFolderLimitSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        existingFolderLimitRow->addItem(existingFolderLimitSpacer);

        existingFolderLimitCheckBox = new OCC::SettingsSwitch(advancedGroupBox);
        existingFolderLimitCheckBox->setObjectName("existingFolderLimitCheckBox");

        existingFolderLimitRow->addWidget(existingFolderLimitCheckBox);


        largeFoldersLayout->addLayout(existingFolderLimitRow);

        stopExistingFolderNowBigSyncSeparator = new QFrame(advancedGroupBox);
        stopExistingFolderNowBigSyncSeparator->setObjectName("stopExistingFolderNowBigSyncSeparator");
        stopExistingFolderNowBigSyncSeparator->setFrameShape(QFrame::Shape::HLine);
        stopExistingFolderNowBigSyncSeparator->setFrameShadow(QFrame::Shadow::Plain);

        largeFoldersLayout->addWidget(stopExistingFolderNowBigSyncSeparator);

        stopExistingFolderNowBigSyncRow = new QHBoxLayout();
        stopExistingFolderNowBigSyncRow->setObjectName("stopExistingFolderNowBigSyncRow");
        stopExistingFolderNowBigSyncLabel = new QLabel(advancedGroupBox);
        stopExistingFolderNowBigSyncLabel->setObjectName("stopExistingFolderNowBigSyncLabel");

        stopExistingFolderNowBigSyncRow->addWidget(stopExistingFolderNowBigSyncLabel);

        stopExistingFolderNowBigSyncSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        stopExistingFolderNowBigSyncRow->addItem(stopExistingFolderNowBigSyncSpacer);

        stopExistingFolderNowBigSyncCheckBox = new OCC::SettingsSwitch(advancedGroupBox);
        stopExistingFolderNowBigSyncCheckBox->setObjectName("stopExistingFolderNowBigSyncCheckBox");

        stopExistingFolderNowBigSyncRow->addWidget(stopExistingFolderNowBigSyncCheckBox);


        largeFoldersLayout->addLayout(stopExistingFolderNowBigSyncRow);

        remotePollIntervalSeparator = new QFrame(advancedGroupBox);
        remotePollIntervalSeparator->setObjectName("remotePollIntervalSeparator");
        remotePollIntervalSeparator->setFrameShape(QFrame::Shape::HLine);
        remotePollIntervalSeparator->setFrameShadow(QFrame::Shadow::Plain);

        largeFoldersLayout->addWidget(remotePollIntervalSeparator);

        horizontalLayoutWidget_remotePollInterval = new QWidget(advancedGroupBox);
        horizontalLayoutWidget_remotePollInterval->setObjectName("horizontalLayoutWidget_remotePollInterval");
        remotePollIntervalRow = new QHBoxLayout(horizontalLayoutWidget_remotePollInterval);
        remotePollIntervalRow->setObjectName("remotePollIntervalRow");
        remotePollIntervalRow->setContentsMargins(0, 0, 0, 0);
        remotePollIntervalLabel = new QLabel(horizontalLayoutWidget_remotePollInterval);
        remotePollIntervalLabel->setObjectName("remotePollIntervalLabel");

        remotePollIntervalRow->addWidget(remotePollIntervalLabel);

        remotePollIntervalSpinBox = new QSpinBox(horizontalLayoutWidget_remotePollInterval);
        remotePollIntervalSpinBox->setObjectName("remotePollIntervalSpinBox");
        remotePollIntervalSpinBox->setMinimum(5);
        remotePollIntervalSpinBox->setMaximum(999999);

        remotePollIntervalRow->addWidget(remotePollIntervalSpinBox);

        labelInterval = new QLabel(horizontalLayoutWidget_remotePollInterval);
        labelInterval->setObjectName("labelInterval");
        labelInterval->setTextFormat(Qt::TextFormat::RichText);
        labelInterval->setOpenExternalLinks(true);
        labelInterval->setTextInteractionFlags(Qt::TextInteractionFlag::LinksAccessibleByKeyboard|Qt::TextInteractionFlag::LinksAccessibleByMouse);

        remotePollIntervalRow->addWidget(labelInterval);

        remotePollIntervalSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        remotePollIntervalRow->addItem(remotePollIntervalSpacer);


        largeFoldersLayout->addWidget(horizontalLayoutWidget_remotePollInterval);


        pageLayout->addWidget(advancedGroupBox);

        syncBehaviorGroupBox = new QGroupBox(OCC__AdvancedSettings);
        syncBehaviorGroupBox->setObjectName("syncBehaviorGroupBox");
        syncBehaviorLayout = new QVBoxLayout(syncBehaviorGroupBox);
        syncBehaviorLayout->setSpacing(0);
        syncBehaviorLayout->setObjectName("syncBehaviorLayout");
        newExternalStorageRow = new QHBoxLayout();
        newExternalStorageRow->setObjectName("newExternalStorageRow");
        newExternalStorageLabel = new QLabel(syncBehaviorGroupBox);
        newExternalStorageLabel->setObjectName("newExternalStorageLabel");

        newExternalStorageRow->addWidget(newExternalStorageLabel);

        newExternalStorageSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        newExternalStorageRow->addItem(newExternalStorageSpacer);

        newExternalStorage = new OCC::SettingsSwitch(syncBehaviorGroupBox);
        newExternalStorage->setObjectName("newExternalStorage");

        newExternalStorageRow->addWidget(newExternalStorage);


        syncBehaviorLayout->addLayout(newExternalStorageRow);

        moveFilesToTrashSeparator = new QFrame(syncBehaviorGroupBox);
        moveFilesToTrashSeparator->setObjectName("moveFilesToTrashSeparator");
        moveFilesToTrashSeparator->setFrameShape(QFrame::Shape::HLine);
        moveFilesToTrashSeparator->setFrameShadow(QFrame::Shadow::Plain);

        syncBehaviorLayout->addWidget(moveFilesToTrashSeparator);

        moveFilesToTrashRow = new QHBoxLayout();
        moveFilesToTrashRow->setObjectName("moveFilesToTrashRow");
        moveFilesToTrashLabel = new QLabel(syncBehaviorGroupBox);
        moveFilesToTrashLabel->setObjectName("moveFilesToTrashLabel");

        moveFilesToTrashRow->addWidget(moveFilesToTrashLabel);

        moveFilesToTrashSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        moveFilesToTrashRow->addItem(moveFilesToTrashSpacer);

        moveFilesToTrashCheckBox = new OCC::SettingsSwitch(syncBehaviorGroupBox);
        moveFilesToTrashCheckBox->setObjectName("moveFilesToTrashCheckBox");

        moveFilesToTrashRow->addWidget(moveFilesToTrashCheckBox);


        syncBehaviorLayout->addLayout(moveFilesToTrashRow);

        showInExplorerNavigationPaneSeparator = new QFrame(syncBehaviorGroupBox);
        showInExplorerNavigationPaneSeparator->setObjectName("showInExplorerNavigationPaneSeparator");
        showInExplorerNavigationPaneSeparator->setFrameShape(QFrame::Shape::HLine);
        showInExplorerNavigationPaneSeparator->setFrameShadow(QFrame::Shadow::Plain);

        syncBehaviorLayout->addWidget(showInExplorerNavigationPaneSeparator);

        showInExplorerNavigationPaneRowWidget = new QWidget(syncBehaviorGroupBox);
        showInExplorerNavigationPaneRowWidget->setObjectName("showInExplorerNavigationPaneRowWidget");
        showInExplorerNavigationPaneRow = new QHBoxLayout(showInExplorerNavigationPaneRowWidget);
        showInExplorerNavigationPaneRow->setObjectName("showInExplorerNavigationPaneRow");
        showInExplorerNavigationPaneRow->setContentsMargins(0, 0, 0, 0);
        showInExplorerNavigationPaneLabel = new QLabel(showInExplorerNavigationPaneRowWidget);
        showInExplorerNavigationPaneLabel->setObjectName("showInExplorerNavigationPaneLabel");

        showInExplorerNavigationPaneRow->addWidget(showInExplorerNavigationPaneLabel);

        showInExplorerNavigationPaneSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        showInExplorerNavigationPaneRow->addItem(showInExplorerNavigationPaneSpacer);

        showInExplorerNavigationPaneCheckBox = new OCC::SettingsSwitch(showInExplorerNavigationPaneRowWidget);
        showInExplorerNavigationPaneCheckBox->setObjectName("showInExplorerNavigationPaneCheckBox");

        showInExplorerNavigationPaneRow->addWidget(showInExplorerNavigationPaneCheckBox);


        syncBehaviorLayout->addWidget(showInExplorerNavigationPaneRowWidget);


        pageLayout->addWidget(syncBehaviorGroupBox);

        advancedActionsGroupBox = new QGroupBox(OCC__AdvancedSettings);
        advancedActionsGroupBox->setObjectName("advancedActionsGroupBox");
        advancedActionsLayout = new QHBoxLayout(advancedActionsGroupBox);
        advancedActionsLayout->setObjectName("advancedActionsLayout");
        advancedActionsSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        advancedActionsLayout->addItem(advancedActionsSpacer);

        ignoredFilesButton = new QPushButton(advancedActionsGroupBox);
        ignoredFilesButton->setObjectName("ignoredFilesButton");

        advancedActionsLayout->addWidget(ignoredFilesButton);

        debugArchiveButton = new QPushButton(advancedActionsGroupBox);
        debugArchiveButton->setObjectName("debugArchiveButton");

        advancedActionsLayout->addWidget(debugArchiveButton);


        pageLayout->addWidget(advancedActionsGroupBox);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        pageLayout->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        newFolderLimitLabel->setBuddy(newFolderLimitCheckBox);
        existingFolderLimitLabel->setBuddy(existingFolderLimitCheckBox);
        stopExistingFolderNowBigSyncLabel->setBuddy(stopExistingFolderNowBigSyncCheckBox);
        newExternalStorageLabel->setBuddy(newExternalStorage);
        moveFilesToTrashLabel->setBuddy(moveFilesToTrashCheckBox);
        showInExplorerNavigationPaneLabel->setBuddy(showInExplorerNavigationPaneCheckBox);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(newFolderLimitCheckBox, newFolderLimitSpinBox);
        QWidget::setTabOrder(newFolderLimitSpinBox, existingFolderLimitCheckBox);
        QWidget::setTabOrder(existingFolderLimitCheckBox, stopExistingFolderNowBigSyncCheckBox);
        QWidget::setTabOrder(stopExistingFolderNowBigSyncCheckBox, remotePollIntervalSpinBox);
        QWidget::setTabOrder(remotePollIntervalSpinBox, newExternalStorage);
        QWidget::setTabOrder(newExternalStorage, moveFilesToTrashCheckBox);
        QWidget::setTabOrder(moveFilesToTrashCheckBox, showInExplorerNavigationPaneCheckBox);
        QWidget::setTabOrder(showInExplorerNavigationPaneCheckBox, ignoredFilesButton);
        QWidget::setTabOrder(ignoredFilesButton, debugArchiveButton);

        retranslateUi(OCC__AdvancedSettings);
        QObject::connect(newFolderLimitCheckBox, SIGNAL(toggled(bool)), newFolderLimitSpinBox, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(OCC__AdvancedSettings);
    } // setupUi

    void retranslateUi(QWidget *OCC__AdvancedSettings)
    {
        advancedGroupBox->setTitle(QString());
        newFolderLimitLabel->setText(QCoreApplication::translate("OCC::AdvancedSettings", "Ask for confirmation before synchronizing new folders larger than", nullptr));
        label->setText(QCoreApplication::translate("OCC::AdvancedSettings", "MB", nullptr));
        existingFolderLimitLabel->setText(QCoreApplication::translate("OCC::AdvancedSettings", "Notify when synchronised folders grow larger than specified limit", nullptr));
        stopExistingFolderNowBigSyncLabel->setText(QCoreApplication::translate("OCC::AdvancedSettings", "Automatically disable synchronisation of folders that overcome limit", nullptr));
        remotePollIntervalLabel->setText(QCoreApplication::translate("OCC::AdvancedSettings", "Server poll interval", nullptr));
        labelInterval->setText(QCoreApplication::translate("OCC::AdvancedSettings", "seconds (if <a href=\"https://github.com/nextcloud/notify_push\">Client Push</a> is unavailable)", nullptr));
        syncBehaviorGroupBox->setTitle(QString());
        newExternalStorageLabel->setText(QCoreApplication::translate("OCC::AdvancedSettings", "Ask for confirmation before synchronizing external storages", nullptr));
        moveFilesToTrashLabel->setText(QCoreApplication::translate("OCC::AdvancedSettings", "Move removed files to trash", nullptr));
        showInExplorerNavigationPaneLabel->setText(QCoreApplication::translate("OCC::AdvancedSettings", "Show sync folders in &Explorer's navigation pane", nullptr));
        advancedActionsGroupBox->setTitle(QString());
        ignoredFilesButton->setText(QCoreApplication::translate("OCC::AdvancedSettings", "Edit &Ignored Files", nullptr));
        debugArchiveButton->setText(QCoreApplication::translate("OCC::AdvancedSettings", "Create Debug Archive", nullptr));
        (void)OCC__AdvancedSettings;
    } // retranslateUi

};

} // namespace OCC

namespace OCC {
namespace Ui {
    class AdvancedSettings: public Ui_AdvancedSettings {};
} // namespace Ui
} // namespace OCC

#endif // UI_ADVANCEDSETTINGS_H
