/****************************************************************************
** Meta object code from reading C++ file 'governancenetworkjob.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../nextcloud-client/src/gui/governance/governancenetworkjob.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'governancenetworkjob.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3OCC20GovernanceNetworkJobE_t {};
} // unnamed namespace

template <> constexpr inline auto OCC::GovernanceNetworkJob::qt_create_metaobjectdata<qt_meta_tag_ZN3OCC20GovernanceNetworkJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OCC::GovernanceNetworkJob",
        "QML.Element",
        "auto",
        "apiVersionChanged",
        "",
        "entityTypeChanged",
        "customEntityTypeChanged",
        "entityIdChanged",
        "started",
        "finished",
        "QJsonDocument",
        "reply",
        "finishedWithError",
        "errorCode",
        "errorMessage",
        "accountChanged",
        "start",
        "jobDone",
        "statusCode",
        "account",
        "AccountPtr",
        "apiVersion",
        "Governance::ApiVersion",
        "entityType",
        "Governance::EntityType",
        "customEntityType",
        "entityId"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'apiVersionChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'entityTypeChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'customEntityTypeChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'entityIdChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'started'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'finished'
        QtMocHelpers::SignalData<void(QJsonDocument)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'finishedWithError'
        QtMocHelpers::SignalData<void(int, const QString &)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 }, { QMetaType::QString, 14 },
        }}),
        // Signal 'accountChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'start'
        QtMocHelpers::SlotData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'jobDone'
        QtMocHelpers::SlotData<void(QJsonDocument, int)>(17, 4, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { QMetaType::Int, 18 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'account'
        QtMocHelpers::PropertyData<AccountPtr>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 7),
        // property 'apiVersion'
        QtMocHelpers::PropertyData<Governance::ApiVersion>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 0),
        // property 'entityType'
        QtMocHelpers::PropertyData<Governance::EntityType>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 1),
        // property 'customEntityType'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 2),
        // property 'entityId'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<GovernanceNetworkJob, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN3OCC20GovernanceNetworkJobE[] = {
    QMetaObject::SuperData::link<OCC::Governance::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject OCC::GovernanceNetworkJob::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3OCC20GovernanceNetworkJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3OCC20GovernanceNetworkJobE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN3OCC20GovernanceNetworkJobE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3OCC20GovernanceNetworkJobE_t>.metaTypes,
    nullptr
} };

void OCC::GovernanceNetworkJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GovernanceNetworkJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->apiVersionChanged(); break;
        case 1: _t->entityTypeChanged(); break;
        case 2: _t->customEntityTypeChanged(); break;
        case 3: _t->entityIdChanged(); break;
        case 4: _t->started(); break;
        case 5: _t->finished((*reinterpret_cast<std::add_pointer_t<QJsonDocument>>(_a[1]))); break;
        case 6: _t->finishedWithError((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 7: _t->accountChanged(); break;
        case 8: _t->start(); break;
        case 9: _t->jobDone((*reinterpret_cast<std::add_pointer_t<QJsonDocument>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GovernanceNetworkJob::*)()>(_a, &GovernanceNetworkJob::apiVersionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (GovernanceNetworkJob::*)()>(_a, &GovernanceNetworkJob::entityTypeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (GovernanceNetworkJob::*)()>(_a, &GovernanceNetworkJob::customEntityTypeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (GovernanceNetworkJob::*)()>(_a, &GovernanceNetworkJob::entityIdChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (GovernanceNetworkJob::*)()>(_a, &GovernanceNetworkJob::started, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (GovernanceNetworkJob::*)(QJsonDocument )>(_a, &GovernanceNetworkJob::finished, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (GovernanceNetworkJob::*)(int , const QString & )>(_a, &GovernanceNetworkJob::finishedWithError, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (GovernanceNetworkJob::*)()>(_a, &GovernanceNetworkJob::accountChanged, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<AccountPtr*>(_v) = _t->account(); break;
        case 1: *reinterpret_cast<Governance::ApiVersion*>(_v) = _t->apiVersion(); break;
        case 2: *reinterpret_cast<Governance::EntityType*>(_v) = _t->entityType(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->customEntityType(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->entityId(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAccount(*reinterpret_cast<AccountPtr*>(_v)); break;
        case 1: _t->setApiVersion(*reinterpret_cast<Governance::ApiVersion*>(_v)); break;
        case 2: _t->setEntityType(*reinterpret_cast<Governance::EntityType*>(_v)); break;
        case 3: _t->setCustomEntityType(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setEntityId(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *OCC::GovernanceNetworkJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OCC::GovernanceNetworkJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3OCC20GovernanceNetworkJobE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QObject::qt_metacast(_clname);
}

int OCC::GovernanceNetworkJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void OCC::GovernanceNetworkJob::apiVersionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void OCC::GovernanceNetworkJob::entityTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void OCC::GovernanceNetworkJob::customEntityTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void OCC::GovernanceNetworkJob::entityIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void OCC::GovernanceNetworkJob::started()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void OCC::GovernanceNetworkJob::finished(QJsonDocument _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void OCC::GovernanceNetworkJob::finishedWithError(int _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void OCC::GovernanceNetworkJob::accountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
