/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.11.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x1,0x32,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x20,0x3,0x45,0x9,0x0,0x52,0xf,0x2d,0x1c,0x50,0x4f,0x1d,
  0xc3,0xca,0x88,0x9d,0x5c,0x4,0xf1,0x4e,0xb2,0xf5,0xba,0x18,0x94,0x84,0xf0,0x0,
  0xa0,0x4f,0x6b,0x8b,0xaa,0xa8,0x7a,0x82,0x30,0xa8,0x7d,0x9f,0x69,0x53,0xd1,0x85,
  0x44,0x6d,0xec,0x8f,0xb2,0xc5,0x8c,0xd6,0xd3,0xd,0xae,0xf7,0x79,0x5f,0xc8,0x4d,
  0x28,0xbb,0x5e,0xcf,0xb4,0xf1,0xad,0xdb,0x56,0x3c,0xb4,0xbf,0xb2,0x4e,0x9a,0xa7,
  0x8f,0x70,0x6e,0xa3,0x43,0xa3,0x2b,0x1e,0xf6,0x6a,0x78,0x9e,0x52,0x1b,0x51,0x7b,
  0xd7,0xb7,0x17,0x7e,0xc2,0x46,0x34,0x5d,0xc9,0xf6,0x3,0x25,0x0,0x23,0x18,0x4,
  0x52,0xc5,0x5b,0x6f,0x4,0x29,0xa5,0xd4,0x73,0xa6,0xf8,0x51,0xd4,0x53,0x14,0x21,
  0x45,0x95,0x68,0x84,0x48,0xf2,0xa3,0x30,0x2e,0xe9,0x55,0x78,0x79,0x86,0xe3,0x38,
  0x6f,0xb5,0x94,0x8b,0x59,0xe2,0xd5,0xbe,0xf,0x1d,0xf5,0xba,0xc9,0xb0,0xd9,0x79,
  0x48,0xaf,0x2e,0xae,0x9f,0xf4,0x32,0x7a,0x58,0x5c,0x2a,0x99,0x6f,0x5d,0x66,0xd0,
  0x7f,0x22,0xb5,0x31,0x6d,0x3a,0xb3,0xb7,0x68,0x33,0xcf,0x59,0x52,0x9e,0xcd,0x5f,
  0x30,0xa0,0x31,0x26,0x91,0x8a,0xc4,0xa2,0x24,0x31,0xb4,0x19,0x40,0x82,0xc3,0xb5,
  0x3,0x59,0x5,0xea,0xa0,0x6c,0x95,0x87,0x8,0x90,0xc9,0x6,0xa,0x6d,0xa3,0x37,
  0xb9,0x41,0xa2,0xa6,0x0,0x2e,0xcb,0xe,0xa6,0x1e,0x5f,0x41,0xda,0xfd,0xcf,0x6c,
  0xbf,0x64,0xa9,0x44,0x28,0x6d,0x1b,0x49,0xc9,0x5d,0x51,0xdb,0x63,0x83,0xe1,0x93,
  0x40,0x55,0x5b,0x73,0x2f,0x9a,0x8f,0x5,0x6f,0x11,0x40,0x9b,0xe,0x17,0x4,0xb2,
  0xb5,0x59,0xde,0x1f,0x35,0x6c,0x68,0xf8,0x34,0x26,0xa5,0x62,0x50,0xd8,0x64,0x4b,
  0x63,0x18,0xe6,0xb3,0x6b,0x7a,0x17,0xb6,0x76,0x4d,0xf4,0xb0,0xe9,0xd5,0xb4,0x59,
  0x5,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // com
  0x0,0x3,
  0x0,0x0,0x6a,0x5d,
  0x0,0x63,
  0x0,0x6f,0x0,0x6d,
    // nextcloud
  0x0,0x9,
  0xf,0xaa,0xdf,0x34,
  0x0,0x6e,
  0x0,0x65,0x0,0x78,0x0,0x74,0x0,0x63,0x0,0x6c,0x0,0x6f,0x0,0x75,0x0,0x64,
    // desktopclient
  0x0,0xd,
  0x3,0x36,0xaf,0x34,
  0x0,0x64,
  0x0,0x65,0x0,0x73,0x0,0x6b,0x0,0x74,0x0,0x6f,0x0,0x70,0x0,0x63,0x0,0x6c,0x0,0x69,0x0,0x65,0x0,0x6e,0x0,0x74,
    // search
  0x0,0x6,
  0x7,0x9b,0x88,0x98,
  0x0,0x73,
  0x0,0x65,0x0,0x61,0x0,0x72,0x0,0x63,0x0,0x68,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9f,0xf5,0xc8,0x5a,0x0,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9f,0xf5,0xc8,0x5a,0x0,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9f,0xf5,0xc8,0x5a,0x0,
  // :/qt/qml/com
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x9f,0xf5,0xc8,0x5a,0x0,
  // :/qt/qml/com/nextcloud
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x9f,0xf5,0xc8,0x5a,0x0,
  // :/qt/qml/com/nextcloud/desktopclient
  0x0,0x0,0x0,0x3a,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x6,
0x0,0x0,0x1,0x9f,0xf5,0xc8,0x5a,0x0,
  // :/qt/qml/com/nextcloud/desktopclient/search
  0x0,0x0,0x0,0x5a,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x7,
0x0,0x0,0x1,0x9f,0xf5,0xc8,0x5a,0x0,
  // :/qt/qml/com/nextcloud/desktopclient/search/qmldir
  0x0,0x0,0x0,0x6c,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9f,0xf5,0xc8,0x5a,0x0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_com_nextcloud_desktopclient_search)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_com_nextcloud_desktopclient_search)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_com_nextcloud_desktopclient_search)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_com_nextcloud_desktopclient_search)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_com_nextcloud_desktopclient_search)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_com_nextcloud_desktopclient_search)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
