/****************************************************************************
** Meta object code from reading C++ file 'governancetypes.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../nextcloud-client/src/gui/governance/governancetypes.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'governancetypes.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3OCC10GovernanceE_t {};
} // unnamed namespace

template <> constexpr inline auto OCC::Governance::qt_create_metaobjectdata<qt_meta_tag_ZN3OCC10GovernanceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OCC::Governance",
        "EntityType",
        "Files",
        "Mails",
        "Custom",
        "LabelType",
        "Sensitivity",
        "Retention",
        "LegalHold",
        "InvalidLabelType",
        "ApiVersion",
        "InvalidApiVersion",
        "Version_1"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'EntityType'
        QtMocHelpers::EnumData<EntityType>(1, 1, QMC::EnumIsScoped).add({
            {    2, EntityType::Files },
            {    3, EntityType::Mails },
            {    4, EntityType::Custom },
        }),
        // enum 'LabelType'
        QtMocHelpers::EnumData<LabelType>(5, 5, QMC::EnumIsScoped).add({
            {    6, LabelType::Sensitivity },
            {    7, LabelType::Retention },
            {    8, LabelType::LegalHold },
            {    9, LabelType::InvalidLabelType },
        }),
        // enum 'ApiVersion'
        QtMocHelpers::EnumData<ApiVersion>(10, 10, QMC::EnumIsScoped).add({
            {   11, ApiVersion::InvalidApiVersion },
            {   12, ApiVersion::Version_1 },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN3OCC10GovernanceE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN3OCC10GovernanceE =
    OCC::Governance::qt_create_metaobjectdata<qt_meta_tag_ZN3OCC10GovernanceE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN3OCC10GovernanceE =
    qt_staticMetaObjectContent_ZN3OCC10GovernanceE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN3OCC10GovernanceE =
    qt_staticMetaObjectContent_ZN3OCC10GovernanceE.relocatingData;

Q_CONSTINIT const QMetaObject OCC::Governance::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN3OCC10GovernanceE.stringdata,
    qt_staticMetaObjectStaticContent_ZN3OCC10GovernanceE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN3OCC10GovernanceE.metaTypes,
    nullptr
} };

QT_WARNING_POP
