/********************************************************************************
** Form generated from reading UI file 'infosettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_INFOSETTINGS_H
#define UI_INFOSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "settingsswitch.h"

namespace OCC {

class Ui_InfoSettings
{
public:
    QVBoxLayout *pageLayout;
    QGroupBox *aboutAndUpdatesGroupBox;
    QHBoxLayout *aboutLayout;
    QLabel *infoAndUpdatesLabel;
    QSpacerItem *aboutSpacer;
    QPushButton *usageDocumentationButton;
    QPushButton *legalNoticeButton;
    QGroupBox *updatesGroupBox;
    QVBoxLayout *updatesGroupBoxLayout;
    QWidget *updatesContainer;
    QVBoxLayout *updatesLayout;
    QHBoxLayout *updateInfoRow;
    QLabel *updateStateLabel;
    QSpacerItem *updateInfoSpacer;
    QLabel *updateChannelLabel;
    QComboBox *updateChannel;
    QPushButton *restoreUpdateChannelButton;
    QFrame *updateControlsSeparator;
    QHBoxLayout *updateControlsRow;
    QLabel *autoCheckForUpdatesLabel;
    QSpacerItem *updateControlsSpacer;
    QPushButton *restartButton;
    QPushButton *updateButton;
    OCC::SettingsSwitch *autoCheckForUpdatesCheckBox;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *OCC__InfoSettings)
    {
        if (OCC__InfoSettings->objectName().isEmpty())
            OCC__InfoSettings->setObjectName("OCC__InfoSettings");
        OCC__InfoSettings->resize(667, 280);
        OCC__InfoSettings->setWindowTitle(QString::fromUtf8("Form"));
        pageLayout = new QVBoxLayout(OCC__InfoSettings);
        pageLayout->setSpacing(12);
        pageLayout->setObjectName("pageLayout");
        pageLayout->setContentsMargins(0, 0, 0, 0);
        aboutAndUpdatesGroupBox = new QGroupBox(OCC__InfoSettings);
        aboutAndUpdatesGroupBox->setObjectName("aboutAndUpdatesGroupBox");
        aboutLayout = new QHBoxLayout(aboutAndUpdatesGroupBox);
        aboutLayout->setObjectName("aboutLayout");
        infoAndUpdatesLabel = new QLabel(aboutAndUpdatesGroupBox);
        infoAndUpdatesLabel->setObjectName("infoAndUpdatesLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(infoAndUpdatesLabel->sizePolicy().hasHeightForWidth());
        infoAndUpdatesLabel->setSizePolicy(sizePolicy);
        infoAndUpdatesLabel->setWordWrap(true);

        aboutLayout->addWidget(infoAndUpdatesLabel);

        aboutSpacer = new QSpacerItem(24, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        aboutLayout->addItem(aboutSpacer);

        usageDocumentationButton = new QPushButton(aboutAndUpdatesGroupBox);
        usageDocumentationButton->setObjectName("usageDocumentationButton");

        aboutLayout->addWidget(usageDocumentationButton);

        legalNoticeButton = new QPushButton(aboutAndUpdatesGroupBox);
        legalNoticeButton->setObjectName("legalNoticeButton");

        aboutLayout->addWidget(legalNoticeButton);


        pageLayout->addWidget(aboutAndUpdatesGroupBox);

        updatesGroupBox = new QGroupBox(OCC__InfoSettings);
        updatesGroupBox->setObjectName("updatesGroupBox");
        updatesGroupBoxLayout = new QVBoxLayout(updatesGroupBox);
        updatesGroupBoxLayout->setSpacing(0);
        updatesGroupBoxLayout->setObjectName("updatesGroupBoxLayout");
        updatesContainer = new QWidget(updatesGroupBox);
        updatesContainer->setObjectName("updatesContainer");
        updatesLayout = new QVBoxLayout(updatesContainer);
        updatesLayout->setSpacing(0);
        updatesLayout->setObjectName("updatesLayout");
        updatesLayout->setContentsMargins(0, 0, 0, 0);
        updateInfoRow = new QHBoxLayout();
        updateInfoRow->setObjectName("updateInfoRow");
        updateStateLabel = new QLabel(updatesContainer);
        updateStateLabel->setObjectName("updateStateLabel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(1);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(updateStateLabel->sizePolicy().hasHeightForWidth());
        updateStateLabel->setSizePolicy(sizePolicy1);
        updateStateLabel->setWordWrap(true);
        updateStateLabel->setOpenExternalLinks(true);

        updateInfoRow->addWidget(updateStateLabel);

        updateInfoSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        updateInfoRow->addItem(updateInfoSpacer);

        updateChannelLabel = new QLabel(updatesContainer);
        updateChannelLabel->setObjectName("updateChannelLabel");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(updateChannelLabel->sizePolicy().hasHeightForWidth());
        updateChannelLabel->setSizePolicy(sizePolicy2);

        updateInfoRow->addWidget(updateChannelLabel);

        updateChannel = new QComboBox(updatesContainer);
        updateChannel->setObjectName("updateChannel");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(updateChannel->sizePolicy().hasHeightForWidth());
        updateChannel->setSizePolicy(sizePolicy3);

        updateInfoRow->addWidget(updateChannel);

        restoreUpdateChannelButton = new QPushButton(updatesContainer);
        restoreUpdateChannelButton->setObjectName("restoreUpdateChannelButton");
        restoreUpdateChannelButton->setEnabled(false);

        updateInfoRow->addWidget(restoreUpdateChannelButton);


        updatesLayout->addLayout(updateInfoRow);

        updateControlsSeparator = new QFrame(updatesContainer);
        updateControlsSeparator->setObjectName("updateControlsSeparator");
        updateControlsSeparator->setFrameShape(QFrame::Shape::HLine);
        updateControlsSeparator->setFrameShadow(QFrame::Shadow::Plain);

        updatesLayout->addWidget(updateControlsSeparator);

        updateControlsRow = new QHBoxLayout();
        updateControlsRow->setObjectName("updateControlsRow");
        autoCheckForUpdatesLabel = new QLabel(updatesContainer);
        autoCheckForUpdatesLabel->setObjectName("autoCheckForUpdatesLabel");

        updateControlsRow->addWidget(autoCheckForUpdatesLabel);

        updateControlsSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        updateControlsRow->addItem(updateControlsSpacer);

        restartButton = new QPushButton(updatesContainer);
        restartButton->setObjectName("restartButton");
        sizePolicy3.setHeightForWidth(restartButton->sizePolicy().hasHeightForWidth());
        restartButton->setSizePolicy(sizePolicy3);

        updateControlsRow->addWidget(restartButton);

        updateButton = new QPushButton(updatesContainer);
        updateButton->setObjectName("updateButton");
        sizePolicy3.setHeightForWidth(updateButton->sizePolicy().hasHeightForWidth());
        updateButton->setSizePolicy(sizePolicy3);

        updateControlsRow->addWidget(updateButton);

        autoCheckForUpdatesCheckBox = new OCC::SettingsSwitch(updatesContainer);
        autoCheckForUpdatesCheckBox->setObjectName("autoCheckForUpdatesCheckBox");
        autoCheckForUpdatesCheckBox->setChecked(true);

        updateControlsRow->addWidget(autoCheckForUpdatesCheckBox);


        updatesLayout->addLayout(updateControlsRow);


        updatesGroupBoxLayout->addWidget(updatesContainer);


        pageLayout->addWidget(updatesGroupBox);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        pageLayout->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        autoCheckForUpdatesLabel->setBuddy(autoCheckForUpdatesCheckBox);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(usageDocumentationButton, legalNoticeButton);
        QWidget::setTabOrder(legalNoticeButton, updateChannel);
        QWidget::setTabOrder(updateChannel, restoreUpdateChannelButton);
        QWidget::setTabOrder(restoreUpdateChannelButton, restartButton);
        QWidget::setTabOrder(restartButton, updateButton);
        QWidget::setTabOrder(updateButton, autoCheckForUpdatesCheckBox);

        retranslateUi(OCC__InfoSettings);

        QMetaObject::connectSlotsByName(OCC__InfoSettings);
    } // setupUi

    void retranslateUi(QWidget *OCC__InfoSettings)
    {
        aboutAndUpdatesGroupBox->setTitle(QString());
        infoAndUpdatesLabel->setText(QCoreApplication::translate("OCC::InfoSettings", "Desktop client x.x.x", nullptr));
        usageDocumentationButton->setText(QCoreApplication::translate("OCC::InfoSettings", "Usage Documentation", nullptr));
        legalNoticeButton->setText(QCoreApplication::translate("OCC::InfoSettings", "Legal Notice", nullptr));
        updatesGroupBox->setTitle(QString());
        updateStateLabel->setText(QString());
        updateChannelLabel->setText(QCoreApplication::translate("OCC::InfoSettings", "Update channel", nullptr));
        restoreUpdateChannelButton->setText(QCoreApplication::translate("OCC::InfoSettings", "Restore &Default", nullptr));
        autoCheckForUpdatesLabel->setText(QCoreApplication::translate("OCC::InfoSettings", "&Automatically check for updates", nullptr));
        restartButton->setText(QCoreApplication::translate("OCC::InfoSettings", "&Restart && Update", nullptr));
        updateButton->setText(QCoreApplication::translate("OCC::InfoSettings", "Check Now", nullptr));
        (void)OCC__InfoSettings;
    } // retranslateUi

};

} // namespace OCC

namespace OCC {
namespace Ui {
    class InfoSettings: public Ui_InfoSettings {};
} // namespace Ui
} // namespace OCC

#endif // UI_INFOSETTINGS_H
